@@ -38,9 +38,8 @@
 #include <eel/eel-string.h>
 #include <eel/eel-vfs-extensions.h>
 #include <eel/eel-xml-extensions.h>
-#include <ghttp.h>
+
 #include <libxml/parser.h>
-#include <libxml/xmlmemory.h>
 #include <gnome.h>
 #include <gtk/gtkeventbox.h>
 #include <libgnome/gnome-i18n.h>
@@ -48,7 +47,6 @@
 #include <libnautilus-private/nautilus-bonobo-extensions.h>
 #include <libnautilus-private/nautilus-file-utilities.h>
 #include <libnautilus-private/nautilus-file.h>
-#include <libnautilus-private/nautilus-font-factory.h>
 #include <libnautilus-private/nautilus-global-preferences.h>
 #include <libnautilus/libnautilus.h>
 #include <libnautilus/nautilus-clipboard.h>
@@ -88,9 +86,10 @@ typedef struct {
 	char *source_mode;
 } ServiceMenuItemParameters;
 
-static void nautilus_text_view_initialize_class (NautilusTextViewClass *klass);
-static void nautilus_text_view_initialize       (NautilusTextView      *view);
-static void nautilus_text_view_destroy          (GtkObject             *object);
+static void nautilus_text_view_class_init (NautilusTextViewClass *klass);
+static void nautilus_text_view_init       (NautilusTextView      *view);
+static void nautilus_text_view_destroy          (BonoboObject          *object);
+static void nautilus_text_view_finalize         (GObject               *object);
 static void nautilus_text_view_update           (NautilusTextView      *text_view);
 static void text_view_load_location_callback    (NautilusView          *view,
 						 const char            *location,
@@ -115,7 +114,7 @@ static void nautilus_text_view_load_uri         (NautilusTextView      *view,
 						 const char            *uri);
 static void font_changed_callback               (gpointer               callback_data);
 
-EEL_DEFINE_CLASS_BOILERPLATE (NautilusTextView,
+EEL_CLASS_BOILERPLATE (NautilusTextView,
                                    nautilus_text_view,
                                    NAUTILUS_TYPE_VIEW)
 
@@ -125,12 +124,15 @@ static const int max_preferred_zoom_levels = (sizeof (text_view_preferred_zoom_l
                                               sizeof (float)) - 1;
 
 static void
-nautilus_text_view_initialize_class (NautilusTextViewClass *klass)
+nautilus_text_view_class_init (NautilusTextViewClass *klass)
 {
-	GtkObjectClass *object_class;
+	GObjectClass *gobject_class;
+	BonoboObjectClass *object_class;
 	
-	object_class = GTK_OBJECT_CLASS (klass);
+	gobject_class = G_OBJECT_CLASS (klass);
+	object_class = BONOBO_OBJECT_CLASS (klass);
 	
+        gobject_class->finalize = nautilus_text_view_finalize;
 	object_class->destroy = nautilus_text_view_destroy;
 
 	/* Text view component fonts */
@@ -145,7 +147,7 @@ nautilus_text_view_initialize_class (NautilusTextViewClass *klass)
 /* initialize ourselves by connecting to the location change signal and allocating our subviews */
 
 static void
-nautilus_text_view_initialize (NautilusTextView *text_view)
+nautilus_text_view_init (NautilusTextView *text_view)
 {
 	GtkWidget *scrolled_window;
 	
@@ -159,27 +161,27 @@ nautilus_text_view_initialize (NautilusTextView *text_view)
 	text_view->details->zoomable = bonobo_zoomable_new ();
 	text_view->details->zoom_index = 3;
 	
-	gtk_signal_connect (GTK_OBJECT (text_view->details->zoomable), "set_zoom_level",
-			    GTK_SIGNAL_FUNC (zoomable_set_zoom_level_callback), text_view);
-	gtk_signal_connect (GTK_OBJECT (text_view->details->zoomable), "zoom_in",
-			    GTK_SIGNAL_FUNC (zoomable_zoom_in_callback), text_view);
-	gtk_signal_connect (GTK_OBJECT (text_view->details->zoomable), "zoom_out",
-			    GTK_SIGNAL_FUNC (zoomable_zoom_out_callback), text_view);
-	gtk_signal_connect (GTK_OBJECT (text_view->details->zoomable), "zoom_to_fit",
-			    GTK_SIGNAL_FUNC (zoomable_zoom_to_fit_callback), text_view);
+	g_signal_connect (text_view->details->zoomable, "set_zoom_level",
+			    G_CALLBACK (zoomable_set_zoom_level_callback), text_view);
+	g_signal_connect (text_view->details->zoomable, "zoom_in",
+			    G_CALLBACK (zoomable_zoom_in_callback), text_view);
+	g_signal_connect (text_view->details->zoomable, "zoom_out",
+			    G_CALLBACK (zoomable_zoom_out_callback), text_view);
+	g_signal_connect (text_view->details->zoomable, "zoom_to_fit",
+			    G_CALLBACK (zoomable_zoom_to_fit_callback), text_view);
 	
 	bonobo_zoomable_set_parameters_full (text_view->details->zoomable,
 					     1.0, .25, 4.0, TRUE, TRUE, FALSE,
 					     text_view_preferred_zoom_levels, NULL,
-					     EEL_N_ELEMENTS (text_view_preferred_zoom_levels));
+					     G_N_ELEMENTS (text_view_preferred_zoom_levels));
 	
 	bonobo_object_add_interface (BONOBO_OBJECT (text_view),
 				     BONOBO_OBJECT (text_view->details->zoomable));
  
     	
-	gtk_signal_connect (GTK_OBJECT (text_view), 
+	g_signal_connect (text_view, 
 			    "load_location",
-			    text_view_load_location_callback, 
+			    G_CALLBACK (text_view_load_location_callback), 
 			    text_view);
 			    	
 	/* allocate a vbox to contain the text widget */
@@ -195,11 +197,11 @@ nautilus_text_view_initialize (NautilusTextView *text_view)
 	/* add signal handlers to the text field to enable/disable the service menu items */
 	gtk_signal_connect_after (GTK_OBJECT (text_view->details->text_display),
                                   "button_release_event",
-                                  GTK_SIGNAL_FUNC (update_service_menu_items), 
+                                  G_CALLBACK (update_service_menu_items), 
                                   text_view);
 	gtk_signal_connect_after (GTK_OBJECT (text_view->details->text_display),
                                   "key_press_event",
-                                  GTK_SIGNAL_FUNC (update_service_menu_items), 
+                                  G_CALLBACK (update_service_menu_items), 
                                   text_view);
 
 	/* set the font of the text object */
@@ -209,11 +211,11 @@ nautilus_text_view_initialize (NautilusTextView *text_view)
 	eel_preferences_add_callback_while_alive (NAUTILUS_PREFERENCES_TEXT_VIEW_FONT,
                                                   font_changed_callback,
                                                   text_view,
-                                                  GTK_OBJECT (text_view));
+                                                  G_OBJECT (text_view));
 	eel_preferences_add_callback_while_alive (NAUTILUS_PREFERENCES_TEXT_VIEW_STANDARD_FONT_SIZE,
                                                   font_changed_callback,
                                                   text_view,
-                                                  GTK_OBJECT (text_view));
+                                                  G_OBJECT (text_view));
 	
 	scrolled_window = gtk_scrolled_window_new (NULL, NULL);
 	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolled_window),
@@ -223,11 +225,10 @@ nautilus_text_view_initialize (NautilusTextView *text_view)
 	gtk_container_add (GTK_CONTAINER (text_view->details->container), scrolled_window);
 
 	/* get notified when we are activated so we can merge in our menu items */
-        gtk_signal_connect (GTK_OBJECT (nautilus_view_get_bonobo_control
-					(NAUTILUS_VIEW (text_view))),
-                            "activate",
-                            merge_bonobo_menu_items,
-                            text_view);
+        g_signal_connect (nautilus_view_get_bonobo_control (NAUTILUS_VIEW (text_view)),
+                          "activate",
+                          G_CALLBACK (merge_bonobo_menu_items),
+                          text_view);
 		 	
 	/* finally, we can show everything */	
 	gtk_widget_show_all (GTK_WIDGET (text_view->details->event_box));
@@ -241,7 +242,7 @@ detach_file (NautilusTextView *text_view)
 }
 
 static void
-nautilus_text_view_destroy (GtkObject *object)
+nautilus_text_view_destroy (BonoboObject *object)
 {
 	NautilusTextView *text_view;
 	
@@ -253,12 +254,23 @@ nautilus_text_view_destroy (GtkObject *object)
 		gnome_vfs_async_cancel (text_view->details->file_handle);
 	}
 	
-        gtk_widget_unref (text_view->details->text_display);
-	g_free (text_view->details->buffer);
+        if (text_view->details->text_display) {
+                gtk_widget_unref (text_view->details->text_display);
+                text_view->details->text_display = NULL;
+        }
+}
 
+static void
+nautilus_text_view_finalize (GObject *object)
+{
+	NautilusTextView *text_view;
+	
+        text_view = NAUTILUS_TEXT_VIEW (object);
+
+	g_free (text_view->details->buffer);
 	g_free (text_view->details);
 
-	EEL_CALL_PARENT (GTK_OBJECT_CLASS, destroy, (object));
+	EEL_CALL_PARENT (G_OBJECT_CLASS, finalize, (object));
 }
 
 /* here's a callback for the async close, which does nothing */
@@ -307,9 +319,10 @@ file_read_callback (GnomeVFSAsyncHandle *vfs_handle,
 
 	/* at EOF, bytes_read is 0 and result is GNOME_VFS_OK */
 	if (result == GNOME_VFS_OK && bytes_read > 0) {
-		/* write the buffer into the text field */
-                display = GTK_TEXT (text_view->details->text_display);
-		if (!GTK_OBJECT_DESTROYED (display)) {
+                if (text_view->details->text_display != NULL) {
+                        /* write the buffer into the text field */
+                        display = GTK_TEXT (text_view->details->text_display);
+                        
                         gtk_text_freeze (display);
                         gtk_text_set_point (display,
                                             gtk_text_get_length (display));
@@ -394,6 +407,7 @@ nautilus_text_view_update (NautilusTextView *text_view)
 	gnome_vfs_async_open (&text_view->details->file_handle,
 			      uri,
 			      GNOME_VFS_OPEN_READ,
+			      GNOME_VFS_PRIORITY_DEFAULT,
 			      file_opened_callback,
 			      text_view);
         g_free (uri);
@@ -547,8 +561,10 @@ service_menu_item_parameters_new (NautilusTextView *text_view, const char *servi
 }
 
 static void
-service_menu_item_parameters_free (ServiceMenuItemParameters *parameters)
+service_menu_item_parameters_free (gpointer data, GClosure *closure)
 {
+	ServiceMenuItemParameters *parameters = (ServiceMenuItemParameters *) data;
+
 	g_free (parameters->service_template);
 	g_free (parameters->source_mode);
 	g_free (parameters);
@@ -607,9 +623,9 @@ add_one_service (NautilusTextView *text_view, BonoboControl *control, const char
 			verb_name = nautilus_bonobo_get_numbered_menu_item_command 
 				(ui, ADDITIONAL_SERVICES_MENU_PATH, *index);	
 			bonobo_ui_component_add_verb_full (ui, verb_name,
-							   handle_service_menu_item,
+							   g_cclosure_new (G_CALLBACK (handle_service_menu_item),
 							   parameters,
-							  (GDestroyNotify) service_menu_item_parameters_free);	   
+							   service_menu_item_parameters_free));	   
 			
 			/* initially disable the item unless it's document-based; it will be enabled if there's a selection */
 			verb_path = g_strdup_printf ("/commands/%s", verb_name);
@@ -647,7 +663,7 @@ add_services_to_menu (NautilusTextView *text_view,
 	char *services_uri, *service_xml_path;
 	
 	services_uri = gnome_vfs_get_uri_from_local_path (services_directory);
-	result = gnome_vfs_directory_list_load (&file_list, services_uri, GNOME_VFS_FILE_INFO_DEFAULT, NULL);
+	result = gnome_vfs_directory_list_load (&file_list, services_uri, GNOME_VFS_FILE_INFO_DEFAULT);
 	
 	if (result != GNOME_VFS_OK) {
 		g_free (services_uri);
@@ -779,8 +795,8 @@ merge_bonobo_menu_items (BonoboControl *control, gboolean state, gpointer user_d
 
 		nautilus_text_view_build_service_menu (text_view, control);
 
-                gtk_signal_connect (GTK_OBJECT (bonobo_control_get_ui_component (control)),
-                                    "ui_event", handle_ui_event, text_view);
+                g_signal_connect (bonobo_control_get_ui_component (control),
+                                    "ui_event", G_CALLBACK (handle_ui_event), text_view);
                 
 		nautilus_clipboard_set_up_editable_in_control (GTK_EDITABLE (text_view->details->text_display),
 						       		control,
@@ -808,8 +824,9 @@ nautilus_text_view_zoom_to_level (NautilusTextView *text_view, int zoom_index)
 	
 	if (pinned_zoom_index != text_view->details->zoom_index) {
 		text_view->details->zoom_index = pinned_zoom_index;
-		bonobo_zoomable_report_zoom_level_changed (text_view->details->zoomable,
-                                                           text_view_preferred_zoom_levels[pinned_zoom_index]);		
+		bonobo_zoomable_report_zoom_level_changed (
+                        text_view->details->zoomable,
+                        text_view_preferred_zoom_levels[pinned_zoom_index], NULL);
 		nautilus_text_view_update_font (text_view);
 	}
  }
