@@ -25,6 +25,7 @@
  */
 
 #include <config.h>
+#include <string.h>
 #include "nautilus-file-operations.h"
 
 #include "nautilus-file-operations-progress.h"
@@ -269,15 +270,16 @@ format_and_ellipsize_uri_for_dialog (const char *uri)
 static char *
 extract_and_ellipsize_file_name_for_dialog (const char *uri)
 {
-	const char *last_part;
+	char *basename;
 	char *unescaped, *result;
 	
-	last_part = g_basename (uri);
-	g_return_val_if_fail (last_part != NULL, NULL);
+	basename = g_path_get_basename (uri);
+	g_return_val_if_fail (basename != NULL, NULL);
 
-	unescaped = gnome_vfs_unescape_string_for_display (last_part);
+	unescaped = gnome_vfs_unescape_string_for_display (basename);
 	result = ellipsize_string_for_dialog (unescaped);
 	g_free (unescaped);
+	g_free (basename);
 
 	return result;
 }
@@ -292,59 +294,6 @@ parent_for_error_dialog (TransferInfo *transfer_info)
 	return transfer_info->parent_view;
 }
 
-static void
-fit_rect_on_screen (GdkRectangle *rect)
-{
-	if (rect->x + rect->width > gdk_screen_width ()) {
-		rect->x = gdk_screen_width () - rect->width;
-	}
-
-	if (rect->y + rect->height > gdk_screen_height ()) {
-		rect->y = gdk_screen_height () - rect->height;
-	}
-
-	if (rect->x < 0) {
-		rect->x = 0;
-	}
-
-	if (rect->y < 0) {
-		rect->y = 0;
-	}
-}
-
-static void
-center_dialog_over_rect (GtkWindow *window, GdkRectangle rect)
-{
-	g_return_if_fail (GTK_WINDOW (window) != NULL);
-
-	fit_rect_on_screen (&rect);
-
-	gtk_widget_set_uposition (GTK_WIDGET (window), 
-		rect.x + rect.width / 2 
-			- GTK_WIDGET (window)->allocation.width / 2,
-		rect.y + rect.height / 2
-			- GTK_WIDGET (window)->allocation.height / 2);
-}
-
-static void
-center_dialog_over_window (GtkWindow *window, GtkWindow *over)
-{
-	GdkRectangle rect;
-	int x, y, w, h;
-
-	g_return_if_fail (GTK_WINDOW (window) != NULL);
-	g_return_if_fail (GTK_WINDOW (over) != NULL);
-
-	gdk_window_get_root_origin (GTK_WIDGET (over)->window, &x, &y);
-	gdk_window_get_size (GTK_WIDGET (over)->window, &w, &h);
-	rect.x = x;
-	rect.y = y;
-	rect.width = w;
-	rect.height = h;
-
-	center_dialog_over_rect (window, rect);
-}
-
 static void
 handle_response_callback (GtkDialog *dialog, int response, TransferInfo *transfer_info)
 {
@@ -384,8 +333,9 @@ create_transfer_dialog (const GnomeVFSXferProgressInfo *progress_info,
 
 	/* Make the progress dialog show up over the window we are copying into */
 	if (transfer_info->parent_view != NULL) {
-		center_dialog_over_window (GTK_WINDOW (transfer_info->progress_dialog), 
-					   GTK_WINDOW (gtk_widget_get_toplevel (transfer_info->parent_view)));
+		gtk_window_set_transient_for (
+			GTK_WINDOW (transfer_info->progress_dialog), 
+			GTK_WINDOW (gtk_widget_get_toplevel (transfer_info->parent_view)));
 	}
 
 	gtk_widget_show (GTK_WIDGET (transfer_info->progress_dialog));
@@ -1547,8 +1497,8 @@ handle_transfer_duplicate (GnomeVFSXferProgressInfo *progress_info,
 			(progress_info->duplicate_name,
 			 progress_info->duplicate_count);
 		break;
-
 	default:
+		break;
 		/* For all other cases we use the name as-is. */
 	}
 
@@ -1968,7 +1918,7 @@ nautilus_file_operations_copy_move (const GList *item_uris,
 				 FALSE,
 				 _("You cannot copy items into the Trash."), 
 				 _("Can't Copy to Trash"),
-				 GNOME_STOCK_BUTTON_OK, NULL, NULL);			
+				 GTK_STOCK_OK, NULL);
 			result = GNOME_VFS_ERROR_NOT_PERMITTED;
 		}
 	}
@@ -2002,7 +1952,7 @@ nautilus_file_operations_copy_move (const GList *item_uris,
 					 ((move_options & GNOME_VFS_XFER_REMOVESOURCE) != 0)
 						 ? _("Can't Change Trash Location")
 						 : _("Can't Copy Trash"),
-					 GNOME_STOCK_BUTTON_OK, NULL, NULL);			
+					 GTK_STOCK_OK, NULL, NULL);			
 
 				result = GNOME_VFS_ERROR_NOT_PERMITTED;
 				break;
@@ -2029,7 +1979,7 @@ nautilus_file_operations_copy_move (const GList *item_uris,
 					 ((move_options & GNOME_VFS_XFER_REMOVESOURCE) != 0) 
 					 ? _("Can't Move Into Self")
 					 : _("Can't Copy Into Self"),
-					 GNOME_STOCK_BUTTON_OK, NULL, NULL);			
+					 GTK_STOCK_OK, NULL, NULL);			
 
 				result = GNOME_VFS_ERROR_NOT_PERMITTED;
 				break;
@@ -2042,7 +1992,7 @@ nautilus_file_operations_copy_move (const GList *item_uris,
 					 FALSE,
 					 _("You cannot copy a file over itself."), 
 					 _("Can't Copy Over Self"), 
-					 GNOME_STOCK_BUTTON_OK, NULL, NULL);			
+					 GTK_STOCK_OK, NULL, NULL);			
 
 				result = GNOME_VFS_ERROR_NOT_PERMITTED;
 				break;
@@ -2302,7 +2252,7 @@ confirm_empty_trash (GtkWidget *parent_view)
 		  "all of the items in the Trash?"),
 		_("Delete Trash Contents?"),
 		_("Empty"),
-		GNOME_STOCK_BUTTON_CANCEL,
+		GTK_STOCK_CANCEL,
 		parent_window);
 
 	gtk_dialog_set_default_response (dialog, GTK_RESPONSE_CANCEL);
