@@ -31,7 +31,7 @@
 G_BEGIN_DECLS
 
 /* Which theme is active */
-#define NAUTILUS_PREFERENCES_THEME				"preferences/theme"
+#define NAUTILUS_PREFERENCES_THEME				"/desktop/gnome/file-views/icon_theme"
 
 /* How wide the sidebar is (or how wide it will be when expanded) */
 #define NAUTILUS_PREFERENCES_SIDEBAR_WIDTH  			"preferences/sidebar_width"
@@ -51,8 +51,8 @@ G_BEGIN_DECLS
 #define NAUTILUS_PREFERENCES_DESKTOP_IS_HOME_DIR                "preferences/desktop_is_home_dir"
 
 /* Display  */
-#define NAUTILUS_PREFERENCES_SHOW_HIDDEN_FILES  		"preferences/show_hidden_files"
-#define NAUTILUS_PREFERENCES_SHOW_BACKUP_FILES  		"preferences/show_backup_files"
+#define NAUTILUS_PREFERENCES_SHOW_HIDDEN_FILES  		"/desktop/gnome/file-views/show_hidden_files"
+#define NAUTILUS_PREFERENCES_SHOW_BACKUP_FILES  		"/desktop/gnome/file-views/show_backup_files"
 #define NAUTILUS_PREFERENCES_SHOW_SPECIAL_FLAGS			"preferences/show_special_flags"
 
 /* Sidebar panels  */
@@ -77,7 +77,6 @@ G_BEGIN_DECLS
 
 /* Content fonts */
 #define NAUTILUS_PREFERENCES_DEFAULT_FONT			"preferences/default_font"
-#define NAUTILUS_PREFERENCES_DEFAULT_SMOOTH_FONT		"preferences/default_smooth_font"
 #define NAUTILUS_PREFERENCES_DEFAULT_FONT_SIZE			"preferences/default_font_size"
 
 /* Single/Double click preference  */
@@ -86,9 +85,6 @@ G_BEGIN_DECLS
 /* Activating executable text files */
 #define NAUTILUS_PREFERENCES_EXECUTABLE_TEXT_ACTIVATION		"preferences/executable_text_activation"
 
-/* Smooth graphics mode (smoother but slower) */
-#define NAUTILUS_PREFERENCES_SMOOTH_GRAPHICS_MODE		"preferences/smooth_graphics_mode"
-
 /* Which views should be displayed for new windows */
 #define NAUTILUS_PREFERENCES_START_WITH_TOOLBAR			"preferences/start_with_toolbar"
 #define NAUTILUS_PREFERENCES_START_WITH_LOCATION_BAR		"preferences/start_with_location_bar"
@@ -121,7 +117,6 @@ enum
 #define NAUTILUS_PREFERENCES_ICON_VIEW_DEFAULT_ZOOM_LEVEL_FONT_SIZE	"icon-view/default_zoom_level_font_size"
 #define NAUTILUS_PREFERENCES_ICON_VIEW_DEFAULT_USE_MANUAL_LAYOUT	"icon-view/default_use_manual_layout"
 #define NAUTILUS_PREFERENCES_ICON_VIEW_FONT				"icon-view/font"
-#define NAUTILUS_PREFERENCES_ICON_VIEW_SMOOTH_FONT			"icon-view/smooth_font"
 
 /* The icon view uses 2 variables to store the sort order and
  * whether to use manual layout.  However, the UI for these
