@@ -60,10 +60,6 @@
 #define MAX_TEXT_WIDTH_STANDARD 135
 #define MAX_TEXT_WIDTH_TIGHTER 80
 
-/* The list of characters that cause line breaks can be localized. */
-static const char untranslated_line_break_characters[] = N_(" -_,;.?/&");
-#define LINE_BREAK_CHARACTERS _(untranslated_line_break_characters)
-
 /* Private part of the NautilusIconCanvasItem structure. */
 struct NautilusIconCanvasItemDetails {
 	/* The image, text, font. */
@@ -106,13 +102,12 @@ struct NautilusIconCanvasItemDetails {
 
 /* Object argument IDs. */
 enum {
-	ARG_0,
-	ARG_EDITABLE_TEXT,
-	ARG_ADDITIONAL_TEXT,
-    	ARG_HIGHLIGHTED_FOR_SELECTION,
-    	ARG_HIGHLIGHTED_AS_KEYBOARD_FOCUS,
-    	ARG_HIGHLIGHTED_FOR_DROP,
-    	ARG_MODIFIER,
+	PROP_0,
+	PROP_EDITABLE_TEXT,
+	PROP_ADDITIONAL_TEXT,
+    	PROP_HIGHLIGHTED_FOR_SELECTION,
+    	PROP_HIGHLIGHTED_AS_KEYBOARD_FOCUS,
+    	PROP_HIGHLIGHTED_FOR_DROP,
 };
 
 typedef enum {
@@ -139,9 +134,6 @@ enum {
 static guint signals[LAST_SIGNAL];
 
 static  gboolean antialias_selection_rectangle = TRUE;
-static	guint32 highlight_background_color = EEL_RGBA_COLOR_PACK (0x00, 0x00, 0x00, 0xFF);
-static	guint32 highlight_text_color	   = EEL_RGBA_COLOR_PACK (0xFF, 0xFF, 0xFF, 0xFF);
-static  guint32 highlight_text_info_color  = EEL_RGBA_COLOR_PACK (0xCC, 0xCC, 0xCC, 0xFF);
 
 static int click_policy_auto_value;
 
@@ -154,10 +146,6 @@ static void     draw_or_measure_label_text           (NautilusIconCanvasItem
 						      GdkDrawable                   *drawable,
 						      int                            icon_left,
 						      int                            icon_bottom);
-static void     draw_or_measure_label_text_aa        (NautilusIconCanvasItem        *item,
-						      GdkPixbuf                     *destination_pixbuf,
-						      int                            icon_left,
-						      int                            icon_bottom);
 static void     draw_label_text                      (NautilusIconCanvasItem        *item,
 						      GdkDrawable                   *drawable,
 						      int                            icon_left,
@@ -188,8 +176,6 @@ static void     draw_label_layout                    (NautilusIconCanvasItem
 
 static gboolean hit_test_stretch_handle              (NautilusIconCanvasItem        *item,
 						      ArtIRect                       canvas_rect);
-static gboolean icon_canvas_item_is_smooth           (const NautilusIconCanvasItem  *icon_item);
-
 static void     update_label_layouts                 (NautilusIconCanvasItem        *item);
 static void     clear_rounded_corners                (GdkPixbuf                     *destination_pixbuf,
 						      GdkPixbuf                     *corner_pixbuf,
@@ -269,61 +255,66 @@ nautilus_icon_canvas_item_invalidate_label_size (NautilusIconCanvasItem *item)
 	}
 }
 
-/* Set_arg handler for the icon item. */
+/* Set property handler for the icon item. */
 static void
-nautilus_icon_canvas_item_set_arg (GtkObject *object, GtkArg *arg, guint arg_id)
+nautilus_icon_canvas_item_set_property (GObject        *object,
+					guint           property_id,
+					const GValue   *value,
+					GParamSpec     *pspec)
 {
 	NautilusIconCanvasItem *item;
 	NautilusIconCanvasItemDetails *details;
 
-	item =  NAUTILUS_ICON_CANVAS_ITEM (object);
+	item = NAUTILUS_ICON_CANVAS_ITEM (object);
 	details = item->details;
 
-	switch (arg_id) {
+	switch (property_id) {
 
-	case ARG_EDITABLE_TEXT:
-		if (eel_strcmp (details->editable_text, GTK_VALUE_STRING (*arg)) == 0) {
+	case PROP_EDITABLE_TEXT:
+		if (eel_strcmp (details->editable_text,
+				g_value_get_string (value)) == 0) {
 			return;
 		}
 
 		g_free (details->editable_text);
-		details->editable_text = g_strdup (GTK_VALUE_STRING (*arg));
+		details->editable_text = g_strdup (g_value_get_string (value));
 		
 		nautilus_icon_canvas_item_invalidate_label_size (item);		
 		break;
 
-	case ARG_ADDITIONAL_TEXT:
-		if (eel_strcmp (details->additional_text, GTK_VALUE_STRING (*arg)) == 0) {
+	case PROP_ADDITIONAL_TEXT:
+		if (eel_strcmp (details->additional_text,
+				g_value_get_string (value)) == 0) {
 			return;
 		}
 
 		g_free (details->additional_text);
-		details->additional_text = g_strdup (GTK_VALUE_STRING (*arg));
+		details->additional_text = g_strdup (g_value_get_string (value));
 		
 		nautilus_icon_canvas_item_invalidate_label_size (item);		
 		break;
 
-	case ARG_HIGHLIGHTED_FOR_SELECTION:
-		if (!details->is_highlighted_for_selection == !GTK_VALUE_BOOL (*arg)) {
+	case PROP_HIGHLIGHTED_FOR_SELECTION:
+		if (!details->is_highlighted_for_selection == !g_value_get_boolean (value)) {
 			return;
 		}
-		details->is_highlighted_for_selection = GTK_VALUE_BOOL (*arg);
+		details->is_highlighted_for_selection = g_value_get_boolean (value);
 		break;
          
-        case ARG_HIGHLIGHTED_AS_KEYBOARD_FOCUS:
-		if (!details->is_highlighted_as_keyboard_focus == !GTK_VALUE_BOOL (*arg)) {
+        case PROP_HIGHLIGHTED_AS_KEYBOARD_FOCUS:
+		if (!details->is_highlighted_as_keyboard_focus == !g_value_get_boolean (value)) {
 			return;
 		}
-		details->is_highlighted_as_keyboard_focus = GTK_VALUE_BOOL (*arg);
+		details->is_highlighted_as_keyboard_focus = g_value_get_boolean (value);
 		break;
 		
-        case ARG_HIGHLIGHTED_FOR_DROP:
-		if (!details->is_highlighted_for_drop == !GTK_VALUE_BOOL (*arg)) {
+        case PROP_HIGHLIGHTED_FOR_DROP:
+		if (!details->is_highlighted_for_drop == !g_value_get_boolean (value)) {
 			return;
 		}
-		details->is_highlighted_for_drop = GTK_VALUE_BOOL (*arg);
+		details->is_highlighted_for_drop = g_value_get_boolean (value);
 		break;
-
+		
 	default:
 		g_warning ("nautilus_icons_view_item_item_set_arg on unknown argument");
 		return;
@@ -332,38 +323,41 @@ nautilus_icon_canvas_item_set_arg (GtkObject *object, GtkArg *arg, guint arg_id)
 	gnome_canvas_item_request_update (GNOME_CANVAS_ITEM (object));
 }
 
-/* Get_arg handler for the icon item */
+/* Get property handler for the icon item */
 static void
-nautilus_icon_canvas_item_get_arg (GtkObject *object, GtkArg *arg, guint arg_id)
+nautilus_icon_canvas_item_get_property (GObject        *object,
+					guint           property_id,
+					GValue         *value,
+					GParamSpec     *pspec)
 {
 	NautilusIconCanvasItemDetails *details;
 	
 	details = NAUTILUS_ICON_CANVAS_ITEM (object)->details;
 	
-	switch (arg_id) {
+	switch (property_id) {
 		
-	case ARG_EDITABLE_TEXT:
-		GTK_VALUE_STRING (*arg) = g_strdup (details->editable_text);
+	case PROP_EDITABLE_TEXT:
+		g_value_set_string (value, details->editable_text);
 		break;
 
-	case ARG_ADDITIONAL_TEXT:
-		GTK_VALUE_STRING (*arg) = g_strdup (details->additional_text);
+	case PROP_ADDITIONAL_TEXT:
+		g_value_set_string (value, details->additional_text);
 		break;
 		
-        case ARG_HIGHLIGHTED_FOR_SELECTION:
-                GTK_VALUE_BOOL (*arg) = details->is_highlighted_for_selection;
+        case PROP_HIGHLIGHTED_FOR_SELECTION:
+		g_value_set_boolean (value, details->is_highlighted_for_selection);
                 break;
 		
-        case ARG_HIGHLIGHTED_AS_KEYBOARD_FOCUS:
-                GTK_VALUE_BOOL (*arg) = details->is_highlighted_as_keyboard_focus;
+        case PROP_HIGHLIGHTED_AS_KEYBOARD_FOCUS:
+		g_value_set_boolean (value, details->is_highlighted_as_keyboard_focus);
                 break;
 		
-        case ARG_HIGHLIGHTED_FOR_DROP:
-                GTK_VALUE_BOOL (*arg) = details->is_highlighted_for_drop;
+        case PROP_HIGHLIGHTED_FOR_DROP:
+		g_value_set_boolean (value, details->is_highlighted_for_drop);
                 break;
 
         default:
-		arg->type = G_TYPE_INVALID;
+		g_warning ("invalid property %d", property_id);
 		break;
 	}
 }
@@ -582,7 +576,7 @@ draw_or_measure_label_text (NautilusIconCanvasItem *item,
 	GnomeCanvasItem *canvas_item;
 	GdkPixbuf *selection_pixbuf;
 	PangoLayout *layout;
-	guint32 label_color;
+	GdkColor *label_color;
 	int layout_width, layout_height;
 	int icon_width;
 	gboolean have_editable, have_additional, needs_highlight;
@@ -637,6 +631,8 @@ draw_or_measure_label_text (NautilusIconCanvasItem *item,
 	height_so_far = 0;
 
 	max_text_width = floor (nautilus_icon_canvas_item_get_max_text_width (item));
+
+	container = NAUTILUS_ICON_CONTAINER (GNOME_CANVAS_ITEM (item)->canvas);	
 				
 	/* if the icon is highlighted, do some set-up */
 	if (needs_highlight && drawable != NULL && !details->is_renaming &&
@@ -647,17 +643,16 @@ draw_or_measure_label_text (NautilusIconCanvasItem *item,
 							   8,
 							   details->text_width,
 							   details->text_height);
-			container = NAUTILUS_ICON_CONTAINER (GNOME_CANVAS_ITEM (item)->canvas);	
 			eel_gdk_pixbuf_fill_rectangle_with_color (selection_pixbuf,
 								  eel_gdk_pixbuf_whole_pixbuf,
-								  container->details->highlight_color);
+								  container->details->highlight_color_rgba);
 			clear_rounded_corners (selection_pixbuf, container->details->highlight_frame, 5);
 			draw_pixbuf (selection_pixbuf, drawable, 
 				     icon_left + (icon_width - details->text_width) / 2,
 				     icon_bottom);
 			g_object_unref (selection_pixbuf);
 		} else {
-			gdk_rgb_gc_set_foreground (gc, highlight_background_color);
+			gdk_gc_set_rgb_fg_color (gc, &container->details->highlight_color);
 			
 			gdk_draw_rectangle
 				(drawable, GTK_WIDGET (GNOME_CANVAS_ITEM (item)->canvas)->style->black_gc, TRUE,
@@ -672,13 +667,11 @@ draw_or_measure_label_text (NautilusIconCanvasItem *item,
 		layout = get_label_layout (&details->editable_text_layout, item, details->editable_text);
 
 		if (drawable != NULL) {
-			if (needs_highlight) {
-				label_color = highlight_text_color;
-			} else {
-				label_color = nautilus_icon_container_get_label_color (NAUTILUS_ICON_CONTAINER (canvas_item->canvas), TRUE);
-			}
+			label_color = nautilus_icon_container_get_label_color
+				(NAUTILUS_ICON_CONTAINER (canvas_item->canvas),
+				 TRUE, needs_highlight);
 
-			gdk_rgb_gc_set_foreground (gc, label_color);
+			gdk_gc_set_rgb_fg_color (gc, label_color);
 			
 			draw_label_layout (item, drawable,
 					   layout, needs_highlight,
@@ -698,13 +691,11 @@ draw_or_measure_label_text (NautilusIconCanvasItem *item,
 		layout = get_label_layout (&details->additional_text_layout, item, details->additional_text);
 
 		if (drawable != NULL) {
-			if (needs_highlight) {
-				label_color = highlight_text_info_color;
-			} else {
-				label_color = nautilus_icon_container_get_label_color (NAUTILUS_ICON_CONTAINER (canvas_item->canvas), FALSE);
-			}
+			label_color = nautilus_icon_container_get_label_color
+				(NAUTILUS_ICON_CONTAINER (canvas_item->canvas),
+				 FALSE, needs_highlight);
 
-			gdk_rgb_gc_set_foreground (gc, label_color);
+			gdk_gc_set_rgb_fg_color (gc, label_color);
 			
 			draw_label_layout (item, drawable,
 					   layout, needs_highlight,
@@ -774,11 +765,7 @@ measure_label_text (NautilusIconCanvasItem *item)
 		return;
 	}
 	
-	if (icon_canvas_item_is_smooth (item)) {
-		draw_or_measure_label_text_aa (item, NULL, 0, 0);
-	} else {
-		draw_or_measure_label_text (item, NULL, 0, 0);
-	}
+	draw_or_measure_label_text (item, NULL, 0, 0);
 }
 
 static void
@@ -828,102 +815,7 @@ draw_stretch_handles (NautilusIconCanvasItem *item, GdkDrawable *drawable,
 	g_free (knob_filename);
 	g_object_unref (knob_pixbuf);	
 
-	gdk_gc_unref (gc);
-}
-
-/* utility routine that uses libart to draw an outlined rectangle */
-static void
-draw_outline_rectangle_aa (GnomeCanvasBuf *buf, int x0, int y0, int x1, int y1, guint outline_color)
-{
-	ArtVpath vpath[12];
-	ArtSVP *path;
-	int halfwidth;
-	
-	halfwidth = 1.0;
-
-	vpath[0].code = ART_MOVETO;
-	vpath[0].x = x0 - halfwidth;
-	vpath[0].y = y0 - halfwidth;
-
-	vpath[1].code = ART_LINETO;
-	vpath[1].x = x0 - halfwidth;
-	vpath[1].y = y1 + halfwidth;
-
-	vpath[2].code = ART_LINETO;
-	vpath[2].x = x1 + halfwidth;
-	vpath[2].y = y1 + halfwidth;
-
-	vpath[3].code = ART_LINETO;
-	vpath[3].x = x1 + halfwidth;
-	vpath[3].y = y0 - halfwidth;
-
-	vpath[4].code = ART_LINETO;
-	vpath[4].x = x0 - halfwidth;
-	vpath[4].y = y0 - halfwidth;
-
-	vpath[5].code = ART_MOVETO;
-	vpath[5].x = x0 + halfwidth;
-	vpath[5].y = y0 + halfwidth;
-
-	vpath[6].code = ART_LINETO;
-	vpath[6].x = x1 - halfwidth;
-	vpath[6].y = y0 + halfwidth;
-
-	vpath[7].code = ART_LINETO;
-	vpath[7].x = x1 - halfwidth;
-	vpath[7].y = y1 - halfwidth;
-
-	vpath[8].code = ART_LINETO;
-	vpath[8].x = x0 + halfwidth;
-	vpath[8].y = y1 - halfwidth;
-
-	vpath[9].code = ART_LINETO;
-	vpath[9].x = x0 + halfwidth;
-	vpath[9].y = y0 + halfwidth;
-
-	vpath[10].code = ART_END;
-	vpath[10].x = 0;
-	vpath[10].y = 0;
-	
-	path = art_svp_from_vpath(vpath);
-	gnome_canvas_render_svp(buf, path, outline_color);
-	art_svp_free(path);	
-}
-
-/* draw the stretch handles in the anti-aliased canvas */
-static void
-draw_stretch_handles_aa (NautilusIconCanvasItem *item, GnomeCanvasBuf *buf,
-			 const ArtIRect *rect)
-{
-	int knob_width, knob_height;
-	GnomeCanvasItem *canvas_item;
-	char *knob_filename;
-	GdkPixbuf *knob_pixbuf;
-	
-	if (!item->details->show_stretch_handles) {
-		return;
-	}
-
-	canvas_item = GNOME_CANVAS_ITEM (item);
-	
-	knob_filename = nautilus_theme_get_image_path ("knob.png");
-	knob_pixbuf = gdk_pixbuf_new_from_file (knob_filename, NULL);
-	knob_width = gdk_pixbuf_get_width (knob_pixbuf);
-	knob_height = gdk_pixbuf_get_height (knob_pixbuf);
-		
-	/* draw a box to connect the dots */
-	draw_outline_rectangle_aa (buf, rect->x0 + 1, rect->y0 + 1,
-				   rect->x1 - 1, rect->y1 - 1,
-				   EEL_RGBA_COLOR_PACK (153, 153, 153, 127));	
-
-	/* now draw the stretch handles themselves  */
-	eel_gnome_canvas_draw_pixbuf (buf, knob_pixbuf, rect->x0, rect->y0);
-	eel_gnome_canvas_draw_pixbuf (buf, knob_pixbuf, rect->x0, rect->y1 - knob_height);
-	eel_gnome_canvas_draw_pixbuf (buf, knob_pixbuf, rect->x1 - knob_width, rect->y0);
-	eel_gnome_canvas_draw_pixbuf (buf, knob_pixbuf, rect->x1 - knob_width, rect->y1 - knob_height);
-			
-	g_free (knob_filename);
-	g_object_unref (knob_pixbuf);	
+	g_object_unref (gc);
 }
 
 static void
@@ -1241,7 +1133,10 @@ create_label_layout (NautilusIconCanvasItem *item,
 		     const char *text)
 {
 	PangoLayout *layout;
+	PangoFontDescription *desc;
+	NautilusIconContainer *container;
 
+	container = NAUTILUS_ICON_CONTAINER (GNOME_CANVAS_ITEM (item)->canvas);
 	layout = pango_layout_new (eel_gnome_canvas_get_pango_context (GNOME_CANVAS_ITEM (item)->canvas));
 
 	pango_layout_set_text (layout, text, -1);
@@ -1249,6 +1144,12 @@ create_label_layout (NautilusIconCanvasItem *item,
 	pango_layout_set_alignment (layout, PANGO_ALIGN_CENTER);
 	pango_layout_set_spacing (layout, LABEL_LINE_SPACING);
 
+	/* Create a font description */
+	desc = pango_font_description_from_string (container->details->font_name);
+	pango_font_description_set_size (desc, container->details->font_size_table [container->details->zoom_level] * PANGO_SCALE);
+	pango_layout_set_font_description (layout, desc);
+	pango_font_description_free (desc);
+	
 	/* if it's prelit, and we're in click-to-activate mode, underline the text */
 	if (item->details->is_prelit && in_single_click_mode ()) {
 		eel_pango_layout_set_underline (layout, PANGO_UNDERLINE_SINGLE);
@@ -1310,162 +1211,6 @@ draw_label_layout (NautilusIconCanvasItem *item,
 	}
 }
 
-static void
-draw_label_layout_aa (NautilusIconCanvasItem *item,
-		      GdkPixbuf *pixbuf,
-		      PangoLayout *layout,
-		      gboolean highlight,
-		      int y,
-		      guint32 color)
-{
-	int x;
-	
-	if (pixbuf == NULL) {
-		return;
-	}
-	if (item->details->is_renaming) {
-		return;
-	}
-	x = (item->details->text_width - pango_layout_get_width (layout) / PANGO_SCALE) / 2;
-
-	if (!highlight) {
-		eel_gdk_pixbuf_draw_layout (pixbuf, x, y, color, layout);
-	} else {
-		/* draw a shadow in black */
-		eel_gdk_pixbuf_draw_layout (pixbuf, x + 2, y + 1,
-					    EEL_RGB_COLOR_BLACK, layout);
-		/* draw smeared-wide text to "embolden" */
-		eel_gdk_pixbuf_draw_layout (pixbuf, x, y, color, layout);
-		eel_gdk_pixbuf_draw_layout (pixbuf, x + 1, y, color, layout);
-	}
-}
-
-static void
-draw_or_measure_label_text_aa (NautilusIconCanvasItem *item,
-			       GdkPixbuf *destination_pixbuf,
-			       int icon_left,
-			       int icon_bottom)
-{
-	NautilusIconCanvasItemDetails *details;
-	int width_so_far, height_so_far;
-	GnomeCanvasItem *canvas_item;
-	PangoLayout *layout;
-	int layout_width, layout_height;
-	gboolean have_editable, have_additional, needs_highlight;
-	guint32 label_color;
-
-	details = item->details;
-	needs_highlight = details->is_highlighted_for_selection || details->is_highlighted_for_drop;
-
-	have_editable = details->editable_text != NULL && details->editable_text[0] != '\0';
-	have_additional = details->additional_text != NULL && details->additional_text[0] != '\0';
-
-	/* No font or no text, then do no work. */
-	if (!have_editable && !have_additional) {
-		details->text_height = 0;
-		details->text_width = 0;			
-		return;
-	}
-	
-#if (defined PERFORMANCE_TEST_MEASURE_DISABLE && defined PERFORMANCE_TEST_DRAW_DISABLE)
-	/* don't do any drawing and fake out the width */
-	details->text_width = 80;
-	details->text_height = 20;
-	return;
-#endif
-
-#ifdef PERFORMANCE_TEST_MEASURE_DISABLE
-	if (destination_pixbuf == NULL) {
-		/* fake out the width */
-		details->text_width = 80;
-		details->text_height = 20;
-		return;
-	}
-#endif
-
-#ifdef PERFORMANCE_TEST_DRAW_DISABLE
-	if (destination_pixbuf != NULL) {
-		return;
-	}
-#endif
-
-	canvas_item = GNOME_CANVAS_ITEM (item);
-	
-	if (destination_pixbuf == NULL) {
-		details->text_width = floor (nautilus_icon_canvas_item_get_max_text_width (item));
-	}
-
-	if (needs_highlight) {
-		icon_bottom += 1; /* leave some space for selection frame */
-	}
-
-	width_so_far = 0;
-	height_so_far = 0;
-
-	if (have_editable) {
-		layout = get_label_layout (&details->editable_text_layout, item, details->editable_text);
-
-		if (needs_highlight) {
-			label_color = highlight_text_color;
-		} else {
-			label_color = nautilus_icon_container_get_label_color (NAUTILUS_ICON_CONTAINER (canvas_item->canvas), TRUE);
-		}
-
-		draw_label_layout_aa (item, destination_pixbuf,
-				      layout, needs_highlight,
-				      icon_bottom + height_so_far, label_color);
-		
-		pango_layout_get_pixel_size (layout, &layout_width, &layout_height);
-
-		width_so_far = MAX (width_so_far, layout_width);
-		height_so_far += layout_height + LABEL_LINE_SPACING;
-		
-		g_object_unref (layout);
-	}
-
-	if (have_additional) {
-		layout = get_label_layout (&details->additional_text_layout, item, details->additional_text);
-
-		if (needs_highlight) {
-			label_color = highlight_text_info_color;
-		} else {
-			label_color = nautilus_icon_container_get_label_color (NAUTILUS_ICON_CONTAINER (canvas_item->canvas), FALSE);
-		}
-		
-		draw_label_layout_aa (item, destination_pixbuf,
-				      layout, needs_highlight,
-				      icon_bottom + height_so_far, label_color);
-		
-		pango_layout_get_pixel_size (layout, &layout_width, &layout_height);
-
-		width_so_far = MAX (width_so_far, layout_width);
-		height_so_far += layout_height + LABEL_LINE_SPACING;
-		
-		g_object_unref (layout);
-	}
-	
-	/* add some extra space for highlighting even when we don't highlight so things won't move */
-	height_so_far += 2; /* extra slop for nicer highlighting */	
-	width_so_far += 8;  /* account for emboldening, plus extra to make it look nicer */
-	
-	if (destination_pixbuf != NULL) {
-		/* Current calculations should match what we measured before drawing.
-		 * This assumes that we will always make a separate call to measure
-		 * before the call to draw. We might later decide to use this function
-		 * differently and change these asserts.
-		 */
-#if (defined PERFORMANCE_TEST_MEASURE_DISABLE || defined PERFORMANCE_TEST_DRAW_DISABLE) 
-		g_assert (height_so_far == details->text_height);
-		g_assert (width_so_far == details->text_width);
-#endif
-	
-	} else {
-		/* If measuring, remember the width & height. */
-		details->text_width = width_so_far;
-		details->text_height = height_so_far;
-	}
-}
-
 /* clear the corners of the selection pixbuf by copying the corners of the passed-in pixbuf */
 static void
 clear_rounded_corners (GdkPixbuf *destination_pixbuf, GdkPixbuf *corner_pixbuf, int corner_size)
@@ -1507,119 +1252,10 @@ clear_rounded_corners (GdkPixbuf *destination_pixbuf, GdkPixbuf *corner_pixbuf,
 			      dest_width - corner_size, dest_height - corner_size);
 }
 
-static void
-draw_label_text_aa (NautilusIconCanvasItem *icon_item, GnomeCanvasBuf *buf, int x, int y, int x_delta)
-{
-	GdkPixbuf *text_pixbuf;
-	NautilusIconContainer *container;
-	
-	gboolean needs_highlight;
-	gboolean have_editable;
-	gboolean have_additional;
-	
-	/* make sure this is really necessary */	
-	have_editable = icon_item->details->editable_text != NULL
-		&& icon_item->details->editable_text[0] != '\0';
-	have_additional = icon_item->details->additional_text != NULL
-		&& icon_item->details->additional_text[0] != '\0';
-
-	/* No font or no text, then do no work. */
-	if (!have_editable && !have_additional) {
-		icon_item->details->text_height = 0;
-		icon_item->details->text_width = 0;			
-		return;
-	}
-	
-	if (icon_item->details->is_renaming) {
-		/* Exit if we are renaming. We don't need to set the text
-		 * width and height to 0 because there is text, it just is not
-		 * drawn to the canvas while the renaming widget is displayed.
-		 */
-		return;
-	}
-		
-	/* Set up the background. */
-	needs_highlight = icon_item->details->is_highlighted_for_selection
-		|| icon_item->details->is_highlighted_for_drop;
-
-	/* Optimizing out the allocation of this pixbuf on every call is a
-	 * measureable speed improvement, but only by around 5%.
-	 * draw_or_measure_label_text_aa accounts for about 90% of the time.
-	 */
- 	text_pixbuf = gdk_pixbuf_new (GDK_COLORSPACE_RGB,
- 				      TRUE,
- 				      8,
- 				      icon_item->details->text_width,
- 				      icon_item->details->text_height);
-	if (needs_highlight) {
-		container = NAUTILUS_ICON_CONTAINER (GNOME_CANVAS_ITEM (icon_item)->canvas);	
-		eel_gdk_pixbuf_fill_rectangle_with_color (text_pixbuf,
-							  eel_gdk_pixbuf_whole_pixbuf,
-							  container->details->highlight_color);
-		clear_rounded_corners (text_pixbuf, container->details->highlight_frame, 5);
-		
-	} else {
-		eel_gdk_pixbuf_fill_rectangle_with_color (text_pixbuf,
-							  eel_gdk_pixbuf_whole_pixbuf,
-							  EEL_RGBA_COLOR_PACK (0, 0, 0, 0));
-	}
-
-	draw_or_measure_label_text_aa (icon_item, text_pixbuf, x_delta, 0);	
-
-	/* Draw the pixbuf containing the label. */
-
-	eel_gnome_canvas_draw_pixbuf (buf, text_pixbuf, x - x_delta, y + LABEL_OFFSET);
-
-	g_object_unref (text_pixbuf);
-
-	/* draw the keyboard selection focus indicator if necessary */
-	if (icon_item->details->is_highlighted_as_keyboard_focus) {
-		draw_outline_rectangle_aa (buf, x - x_delta + 1, y + 1,
-					   x - x_delta + icon_item->details->text_width,
-					   y + icon_item->details->text_height,
-					   EEL_RGBA_COLOR_PACK (153, 153, 153, 127));
-	}
-}
-
-/* draw the item for anti-aliased mode */
 static void
 nautilus_icon_canvas_item_render (GnomeCanvasItem *item, GnomeCanvasBuf *buf)
 {
-	ArtIRect icon_rect, emblem_rect;
-	EmblemLayout emblem_layout;
-	GdkPixbuf *emblem_pixbuf, *temp_pixbuf;
-	NautilusIconCanvasItem *icon_item;
-	int x_delta;
-
-	icon_item = NAUTILUS_ICON_CANVAS_ITEM (item);
-	
-	/* map the pixbuf for selection or other effects */
-	temp_pixbuf = map_pixbuf (icon_item);
-
-	icon_rect = icon_item->details->canvas_rect;
-
-	if (buf->is_bg) {
-		gnome_canvas_buf_ensure_buf (buf);
-		buf->is_bg = FALSE;
-	}
-
-	/* draw the icon */
-	eel_gnome_canvas_draw_pixbuf (buf, temp_pixbuf, icon_rect.x0, icon_rect.y0);
-
-	g_object_unref (temp_pixbuf);
-
-	/* draw the emblems */	
-	emblem_layout_reset (&emblem_layout, icon_item, icon_rect);
-	while (emblem_layout_next (&emblem_layout, &emblem_pixbuf, &emblem_rect)) {
-		eel_gnome_canvas_draw_pixbuf (buf, emblem_pixbuf, emblem_rect.x0, emblem_rect.y0);
-	}
-
-	/* draw the stretch handles */
-	draw_stretch_handles_aa (icon_item, buf, &icon_rect);
-		
-	/* draw the text */
-	x_delta = (icon_item->details->text_width - (icon_rect.x1 - icon_rect.x0)) / 2;
-	draw_label_text_aa (icon_item, buf, icon_rect.x0, icon_rect.y1, x_delta);
+	g_warning ("NautilusIconCanvasItem does not support the anti-aliased canvas");
 }
 
 
@@ -1929,19 +1565,6 @@ nautilus_icon_canvas_item_set_show_stretch_handles (NautilusIconCanvasItem *item
 	gnome_canvas_item_request_update (GNOME_CANVAS_ITEM (item));
 }
 
-/* Check whether the item is in smooth mode */
-static gboolean
-icon_canvas_item_is_smooth (const NautilusIconCanvasItem *icon_item)
-{
-	GnomeCanvas *parent_canvas;
-
-	g_return_val_if_fail (NAUTILUS_IS_ICON_CANVAS_ITEM (icon_item), FALSE);
-
-	parent_canvas = GNOME_CANVAS (GNOME_CANVAS_ITEM (icon_item)->canvas);
-
-	return parent_canvas->aa;
-}
-
 /* Check if one of the stretch handles was hit. */
 static gboolean
 hit_test_stretch_handle (NautilusIconCanvasItem *item,
@@ -2051,28 +1674,57 @@ nautilus_icon_canvas_item_get_max_text_width (NautilusIconCanvasItem *item)
 static void
 nautilus_icon_canvas_item_class_init (NautilusIconCanvasItemClass *class)
 {
-	GtkObjectClass *object_class;
+	GObjectClass *object_class;
 	GnomeCanvasItemClass *item_class;
 
-	object_class = GTK_OBJECT_CLASS (class);
+	object_class = G_OBJECT_CLASS (class);
 	item_class = GNOME_CANVAS_ITEM_CLASS (class);
 
-	gtk_object_add_arg_type	("NautilusIconCanvasItem::editable_text",
-				 G_TYPE_STRING, GTK_ARG_READWRITE, ARG_EDITABLE_TEXT);
-	gtk_object_add_arg_type	("NautilusIconCanvasItem::additional_text",
-				 G_TYPE_STRING, GTK_ARG_READWRITE, ARG_ADDITIONAL_TEXT);
-	gtk_object_add_arg_type	("NautilusIconCanvasItem::highlighted_for_selection",
-				 G_TYPE_BOOLEAN, GTK_ARG_READWRITE, ARG_HIGHLIGHTED_FOR_SELECTION);
-	gtk_object_add_arg_type	("NautilusIconCanvasItem::highlighted_as_keyboard_focus",
-				 G_TYPE_BOOLEAN, GTK_ARG_READWRITE, ARG_HIGHLIGHTED_AS_KEYBOARD_FOCUS);
-	gtk_object_add_arg_type	("NautilusIconCanvasItem::highlighted_for_drop",
-				 G_TYPE_BOOLEAN, GTK_ARG_READWRITE, ARG_HIGHLIGHTED_FOR_DROP);
+	object_class->finalize = nautilus_icon_canvas_item_finalize;
+	object_class->set_property = nautilus_icon_canvas_item_set_property;
+	object_class->get_property = nautilus_icon_canvas_item_get_property;
 
-	G_OBJECT_CLASS (class)->finalize = nautilus_icon_canvas_item_finalize;
+        g_object_class_install_property (
+		object_class,
+		PROP_EDITABLE_TEXT,
+		g_param_spec_string ("editable_text",
+				     _("editable text"),
+				     _("the editable label"),
+				     "", G_PARAM_READWRITE));
 
-	object_class->set_arg = nautilus_icon_canvas_item_set_arg;
-	object_class->get_arg = nautilus_icon_canvas_item_get_arg;
+        g_object_class_install_property (
+		object_class,
+		PROP_ADDITIONAL_TEXT,
+		g_param_spec_string ("additional_text",
+				     _("additional text"),
+				     _("some more text"),
+				     "", G_PARAM_READWRITE));
 
+        g_object_class_install_property (
+		object_class,
+		PROP_HIGHLIGHTED_FOR_SELECTION,
+		g_param_spec_boolean ("highlighted_for_selection",
+				      _("highlighted for selection"),
+				      _("whether we are highlighted for a selection"),
+				      FALSE, G_PARAM_READWRITE)); 
+
+        g_object_class_install_property (
+		object_class,
+		PROP_HIGHLIGHTED_AS_KEYBOARD_FOCUS,
+		g_param_spec_boolean ("highlighted_as_keyboard_focus",
+				      _("highlighted as keyboard focus"),
+				      _("whether we are highlighted to render keyboard focus"),
+				      FALSE, G_PARAM_READWRITE)); 
+
+
+        g_object_class_install_property (
+		object_class,
+		PROP_HIGHLIGHTED_FOR_DROP,
+		g_param_spec_boolean ("highlighted_for_drop",
+				      _("highlighted for drop"),
+				      _("whether we are highlighted for a D&D drop"),
+				      FALSE, G_PARAM_READWRITE)); 
+	
 	signals[BOUNDS_CHANGED]
 		= g_signal_new ("bounds_changed",
 		                G_TYPE_FROM_CLASS (class),
@@ -2080,7 +1732,7 @@ nautilus_icon_canvas_item_class_init (NautilusIconCanvasItemClass *class)
 		                G_STRUCT_OFFSET (NautilusIconCanvasItemClass,
 						     bounds_changed),
 		                NULL, NULL,
-		                gtk_marshal_VOID__VOID,
+		                g_cclosure_marshal_VOID__VOID,
 		                G_TYPE_NONE, 0);
 
 	item_class->update = nautilus_icon_canvas_item_update;
