@@ -26,8 +26,7 @@
 #ifndef NAUTILUS_LINK_HISTORICAL_H
 #define NAUTILUS_LINK_HISTORICAL_H
 
-#include "nautilus-file.h"
-#include <gdk/gdk.h>
+#include <libnautilus-private/nautilus-link.h>
 
 gboolean         nautilus_link_historical_local_create                      (const char        *directory_path,
 									     const char        *name,
@@ -52,10 +51,8 @@ char *           nautilus_link_historical_get_link_uri_given_file_contents  (con
 char *           nautilus_link_historical_get_link_icon_given_file_contents (const char        *link_file_contents,
 									     int                link_file_size);
 
-#if GNOME2_CONVERSION_COMPLETE
-void             nautilus_link_historical_local_create_from_gnome_entry     (GnomeDesktopEntry *entry,
+void             nautilus_link_historical_local_create_from_gnome_entry     (GnomeDesktopItem  *entry,
 									     const char        *dest_path,
 									     const GdkPoint    *position);
-#endif
 								 								 
 #endif /* NAUTILUS_LINK_HISTORICAL_H */
