@@ -68,20 +68,20 @@ enum {
 
 static guint signals[LAST_SIGNAL];
 
-static void     nautilus_merged_directory_initialize       (gpointer                 object,
+static void     nautilus_merged_directory_init       (gpointer                 object,
 							    gpointer                 klass);
-static void     nautilus_merged_directory_initialize_class (gpointer                 klass);
+static void     nautilus_merged_directory_class_init (gpointer                 klass);
 static void     remove_all_real_directories                (NautilusMergedDirectory *merged);
 static guint    merged_callback_hash                       (gconstpointer            merged_callback);
 static gboolean merged_callback_equal                      (gconstpointer            merged_callback,
 							    gconstpointer            merged_callback_2);
 
-EEL_DEFINE_CLASS_BOILERPLATE (NautilusMergedDirectory,
+EEL_CLASS_BOILERPLATE (NautilusMergedDirectory,
 				   nautilus_merged_directory,
 				   NAUTILUS_TYPE_DIRECTORY)
 
 static void
-nautilus_merged_directory_initialize (gpointer object, gpointer klass)
+nautilus_merged_directory_init (gpointer object, gpointer klass)
 {
 	NautilusMergedDirectory *merged;
 
@@ -500,9 +500,9 @@ merged_add_real_directory (NautilusMergedDirectory *merged,
 	merged->details->directories_not_done_loading = g_list_prepend
 		(merged->details->directories_not_done_loading, real_directory);
 
-	gtk_signal_connect (GTK_OBJECT (real_directory),
+	g_signal_connect (real_directory,
 			    "done_loading",
-			    done_loading_callback,
+			    G_CALLBACK (done_loading_callback),
 			    merged);
 
 	/* FIXME bugzilla.gnome.org 45084: The done_loading part won't work for the case where
@@ -515,13 +515,13 @@ merged_add_real_directory (NautilusMergedDirectory *merged,
 			      real_directory);
 	/* FIXME bugzilla.gnome.org 42541: Do we need to add the directory to callbacks too? */
 
-	gtk_signal_connect (GTK_OBJECT (real_directory),
+	g_signal_connect (real_directory,
 			    "files_added",
-			    forward_files_added_cover,
+			    G_CALLBACK (forward_files_added_cover),
 			    merged);
-	gtk_signal_connect (GTK_OBJECT (real_directory),
+	g_signal_connect (real_directory,
 			    "files_changed",
-			    forward_files_changed_cover,
+			    G_CALLBACK (forward_files_changed_cover),
 			    merged);
 }
 
@@ -538,8 +538,8 @@ nautilus_merged_directory_add_real_directory (NautilusMergedDirectory *merged,
 		return;
 	}
 
-	gtk_signal_emit (GTK_OBJECT (merged),
-			 signals[ADD_REAL_DIRECTORY],
+	g_signal_emit (merged,
+			 signals[ADD_REAL_DIRECTORY], 0,
 			 real_directory);
 }
 
@@ -586,7 +586,9 @@ merged_remove_real_directory (NautilusMergedDirectory *merged,
 		 real_directory);
 
 	/* Disconnect all the signals. */
-	gtk_signal_disconnect_by_data (GTK_OBJECT (real_directory), merged);
+	g_signal_handlers_disconnect_matched (
+		real_directory, G_SIGNAL_MATCH_DATA,
+		0, 0, NULL, NULL, merged);
 
 	/* Remove from our list of directories. */
 	merged->details->directories = g_list_remove
@@ -607,8 +609,8 @@ nautilus_merged_directory_remove_real_directory (NautilusMergedDirectory *merged
 		return;
 	}
 
-	gtk_signal_emit (GTK_OBJECT (merged),
-			 signals[REMOVE_REAL_DIRECTORY],
+	g_signal_emit (merged,
+			 signals[REMOVE_REAL_DIRECTORY], 0,
 			 real_directory);
 }
 
@@ -622,7 +624,7 @@ remove_all_real_directories (NautilusMergedDirectory *merged)
 }
 
 static void
-nautilus_merged_directory_initialize_class (gpointer klass)
+nautilus_merged_directory_class_init (gpointer klass)
 {
 	GtkObjectClass *object_class;
 	NautilusDirectoryClass *directory_class;
@@ -647,21 +649,21 @@ nautilus_merged_directory_initialize_class (gpointer klass)
 	merged_directory_class->remove_real_directory = merged_remove_real_directory;
 
 	signals[ADD_REAL_DIRECTORY] 
-		= gtk_signal_new ("add_real_directory",
-				  GTK_RUN_LAST,
-				  object_class->type,
-				  GTK_SIGNAL_OFFSET (NautilusMergedDirectoryClass, 
-						     add_real_directory),
-				  gtk_marshal_NONE__POINTER,
-				  GTK_TYPE_NONE, 1, GTK_TYPE_POINTER);
+		= g_signal_new ("add_real_directory",
+		                G_TYPE_FROM_CLASS (object_class),
+		                G_SIGNAL_RUN_LAST,
+		                G_STRUCT_OFFSET (NautilusMergedDirectoryClass, 
+						 add_real_directory),
+		                NULL, NULL,
+		                g_cclosure_marshal_VOID__POINTER,
+		                G_TYPE_NONE, 1, G_TYPE_POINTER);
 	signals[REMOVE_REAL_DIRECTORY] 
-		= gtk_signal_new ("remove_real_directory",
-				  GTK_RUN_LAST,
-				  object_class->type,
-				  GTK_SIGNAL_OFFSET (NautilusMergedDirectoryClass, 
-						     remove_real_directory),
-				  gtk_marshal_NONE__POINTER,
-				  GTK_TYPE_NONE, 1, GTK_TYPE_POINTER);
-
-	gtk_object_class_add_signals (object_class, signals, LAST_SIGNAL);				  
+		= g_signal_new ("remove_real_directory",
+		                G_TYPE_FROM_CLASS (object_class),
+		                G_SIGNAL_RUN_LAST,
+		                G_STRUCT_OFFSET (NautilusMergedDirectoryClass, 
+						 remove_real_directory),
+		                NULL, NULL,
+		                g_cclosure_marshal_VOID__POINTER,
+		                G_TYPE_NONE, 1, G_TYPE_POINTER);
 }
