@@ -61,14 +61,9 @@ typedef struct {
 	char *no_undo_menu_item_hint;
 } UndoMenuHandlerConnection;
 
-/* GtkObject */
-static void nautilus_undo_manager_class_init (NautilusUndoManagerClass  *class);
-static void nautilus_undo_manager_init       (NautilusUndoManager       *item);
-
-EEL_BONOBO_BOILERPLATE_FULL (NautilusUndoManager,
+BONOBO_CLASS_BOILERPLATE_FULL (NautilusUndoManager, nautilus_undo_manager,
 			       Nautilus_Undo_Manager,
-			       nautilus_undo_manager,
-			       BONOBO_OBJECT_TYPE)
+			       BonoboObject, BONOBO_OBJECT_TYPE)
 
 static void
 release_transaction (NautilusUndoManager *manager)
@@ -162,7 +157,7 @@ nautilus_undo_manager_new (void)
 }
 
 static void
-nautilus_undo_manager_init (NautilusUndoManager *manager)
+nautilus_undo_manager_instance_init (NautilusUndoManager *manager)
 {
 	manager->details = g_new0 (NautilusUndoManagerDetails, 1);
 }
@@ -222,9 +217,8 @@ nautilus_undo_manager_attach (NautilusUndoManager *manager, GObject *target)
 	g_return_if_fail (NAUTILUS_IS_UNDO_MANAGER (manager));
 	g_return_if_fail (G_IS_OBJECT (target));
 
-	nautilus_undo_attach_undo_manager
-		(G_OBJECT (target),
-		 bonobo_object_corba_objref (BONOBO_OBJECT (manager)));
+	nautilus_undo_attach_undo_manager (
+		G_OBJECT (target), BONOBO_OBJREF (manager));
 }
 
 void
@@ -235,7 +229,7 @@ nautilus_undo_manager_add_interface (NautilusUndoManager *manager, BonoboObject
 	g_return_if_fail (NAUTILUS_IS_UNDO_MANAGER (manager));
 	g_return_if_fail (BONOBO_IS_OBJECT (object));
 
-	context = nautilus_undo_context_new (bonobo_object_corba_objref (BONOBO_OBJECT (manager)));
+	context = nautilus_undo_context_new (BONOBO_OBJREF (manager));
 	bonobo_object_add_interface (object, BONOBO_OBJECT (context));
 }
 
@@ -346,9 +340,9 @@ nautilus_undo_manager_class_init (NautilusUndoManagerClass *class)
 		 G_TYPE_FROM_CLASS (class),
 		 G_SIGNAL_RUN_LAST,
 		 G_STRUCT_OFFSET (NautilusUndoManagerClass,
-				    changed),
+				  changed),
 		 NULL, NULL,
-		 gtk_marshal_NONE__NONE,
+		 g_cclosure_marshal_VOID__VOID,
 		 G_TYPE_NONE, 0);
 
 	class->epv.append = corba_append;
