@@ -32,6 +32,7 @@
 #include <gtk/gtkvbox.h>
 #include <libgnome/gnome-i18n.h>
 #include <libgnomeui/gnome-uidefs.h>
+#include <eel/eel-debug.h>
 #include <eel/eel-gdk-extensions.h>
 #include <eel/eel-glib-extensions.h>
 #include <eel/eel-gtk-extensions.h>
@@ -49,7 +50,7 @@
 
 typedef struct {
         GtkLabel *progress_label;
-        GtkProgress *progress_bar;
+        GtkProgressBar *progress_bar;
 } ProgressChangeData;
 
 typedef struct {
@@ -75,8 +76,10 @@ get_index_percentage_complete (void)
 static void
 set_close_hides_for_dialog (GtkDialog *dialog)
 {
+#if GNOME2_CONVERSION_COMPLETE
         gtk_dialog_set_close (dialog, TRUE /*click_closes*/);
         gtk_dialog_close_hides (dialog, TRUE /*just_hide*/);
+#endif
 
 }
 
@@ -100,7 +103,8 @@ update_progress_display (gpointer callback_data)
         progress_string = get_text_for_progress_label ();
         gtk_label_set_text (progress_label, progress_string);
         g_free (progress_string);
-        gtk_progress_set_value (progress_change_data->progress_bar, get_index_percentage_complete ());
+        gtk_progress_bar_set_fraction (progress_change_data->progress_bar, 
+                                       get_index_percentage_complete () / 100.0f);
 
 
         return TRUE;
@@ -111,7 +115,9 @@ dialog_close_cover (gpointer dialog_data)
 {
         g_assert (GTK_IS_DIALOG (dialog_data));
 
+#if GNOME2_CONVERSION_COMPLETE
         gtk_dialog_close (dialog_data);
+#endif
 }
 
 static void
@@ -119,14 +125,16 @@ show_index_progress_dialog (void)
 {
         int callback_id;
         
+#if GNOME2_CONVERSION_COMPLETE
         gtk_dialog_close (dialogs->last_index_time_dialog);
+#endif
         gtk_widget_show_all (GTK_WIDGET (dialogs->index_in_progress_dialog));
         callback_id = medusa_execute_once_when_system_state_changes (dialog_close_cover,
                                                                      dialogs->index_in_progress_dialog);
-        gtk_signal_connect_object (GTK_OBJECT (dialogs->index_in_progress_dialog),
-                                   "destroy",
-                                   medusa_remove_state_changed_function,
-                                   GINT_TO_POINTER (callback_id));
+        g_signal_connect_swapped (dialogs->index_in_progress_dialog,
+                                  "destroy",
+                                  G_CALLBACK (medusa_remove_state_changed_function),
+                                  GINT_TO_POINTER (callback_id));
 }
 
 
@@ -135,14 +143,16 @@ show_last_index_time_dialog (void)
 {
         int callback_id;
 
+#if GNOME2_CONVERSION_COMPLETE
         gtk_dialog_close (dialogs->index_in_progress_dialog);
+#endif
         gtk_widget_show_all (GTK_WIDGET (dialogs->last_index_time_dialog));
         callback_id = medusa_execute_once_when_system_state_changes (dialog_close_cover,
                                                                      dialogs->last_index_time_dialog);
-        gtk_signal_connect_object (GTK_OBJECT (dialogs->last_index_time_dialog),
-                                   "destroy",
-                                   medusa_remove_state_changed_function,
-                                   GINT_TO_POINTER (callback_id));
+        g_signal_connect_swapped (dialogs->last_index_time_dialog,
+                                  "destroy",
+                                  G_CALLBACK (medusa_remove_state_changed_function),
+                                  GINT_TO_POINTER (callback_id));
 }
 
 static GtkDialog *
@@ -200,8 +210,8 @@ index_progress_dialog_new (void)
 
         embedded_vbox = gtk_vbox_new (FALSE, GNOME_PAD_SMALL);
 
-        gtk_progress_set_show_text (GTK_PROGRESS (indexing_progress_bar), FALSE);
-        gtk_progress_configure (GTK_PROGRESS (indexing_progress_bar), percentage_complete, 0, 100);
+        /* turn off text display by setting text to NULL */
+        gtk_progress_bar_set_text (GTK_PROGRESS_BAR (indexing_progress_bar), NULL);
         /* Put the progress bar in an hbox to make it a more sane size */
         gtk_box_pack_start (GTK_BOX (embedded_vbox), indexing_progress_bar, FALSE, FALSE, 0);
 
@@ -220,7 +230,7 @@ index_progress_dialog_new (void)
         /* Keep the dialog current with actual indexing progress */
         progress_data = g_new (ProgressChangeData, 1);
         progress_data->progress_label = GTK_LABEL (progress_label);
-        progress_data->progress_bar = GTK_PROGRESS (indexing_progress_bar);
+        progress_data->progress_bar = GTK_PROGRESS_BAR (indexing_progress_bar);
         timeout_id = gtk_timeout_add_full (PROGRESS_UPDATE_INTERVAL,
                                            update_progress_display,
                                            NULL,
@@ -228,7 +238,7 @@ index_progress_dialog_new (void)
                                            g_free);
         g_signal_connect (progress_bar_hbox,
                             "destroy",
-                            timeout_remove_callback,
+			    G_CALLBACK (timeout_remove_callback),
                             GUINT_TO_POINTER (timeout_id));
         
         return dialog;
@@ -263,15 +273,15 @@ show_indexing_info_dialog (void)
                 
                 callback_id = medusa_execute_once_when_system_state_changes (dialog_close_cover,
                                                                              dialog_shown);
-                gtk_signal_connect_object (GTK_OBJECT (dialog_shown),
-                                           "destroy",
-                                           medusa_remove_state_changed_function,
-                                           GINT_TO_POINTER (callback_id));
+                g_signal_connect_swapped (G_OBJECT (dialog_shown),
+                                          "destroy",
+                                          G_CALLBACK (medusa_remove_state_changed_function),
+                                          GINT_TO_POINTER (callback_id));
                 return;
         }
 	if (dialogs == NULL) {
                 dialogs = g_new0 (IndexingInfoDialogs, 1);
-                g_atexit (destroy_indexing_info_dialogs_on_exit);
+                eel_debug_call_at_shutdown (destroy_indexing_info_dialogs_on_exit);
                 
                 dialogs->last_index_time_dialog = last_index_time_dialog_new ();
                 dialogs->index_in_progress_dialog = index_progress_dialog_new ();
