@@ -49,6 +49,7 @@
 #include <libgnomeui/gnome-uidefs.h>
 #include <libgnomevfs/gnome-vfs.h>
 #include <libnautilus-private/nautilus-entry.h>
+#include <libnautilus-private/nautilus-icon-dnd.h>
 #include <libnautilus/nautilus-clipboard.h>
 #include <stdio.h>
 #include <string.h>
@@ -133,11 +134,7 @@ drag_data_received_callback (GtkWidget *widget,
 	g_assert (data != NULL);
 	g_assert (callback_data == NULL);
 
-#if GNOME2_CONVERSION_COMPLETE
-	names = gnome_uri_list_extract_uris (data->data);
-#else
-	names = NULL;
-#endif
+	names = nautilus_icon_dnd_uri_list_extract_uris (data->data);
 
 	if (names == NULL) {
 		g_warning ("No D&D URI's");
@@ -155,13 +152,15 @@ drag_data_received_callback (GtkWidget *widget,
 		prompt = g_strdup_printf (_("Do you want to view these %d locations "
 					  "in separate windows?"), 
 					  name_count);
+		/* eel_run_simple_dialog should really take in pairs
+		 * like gtk_dialog_new_with_buttons() does. */
 		new_windows_for_extras = eel_run_simple_dialog 
 			(GTK_WIDGET (nautilus_location_bar_get_window (widget)),
 			 TRUE,
 			 prompt,
 			 _("View in Multiple Windows?"),
 			 GTK_STOCK_OK, GTK_STOCK_CANCEL,
-			 NULL) == GNOME_OK;
+			 NULL) == 0 /* GNOME_OK */;
 
 		g_free (prompt);
 		
@@ -182,10 +181,8 @@ drag_data_received_callback (GtkWidget *widget,
 			nautilus_window_go_to (new_window, node->data);
 		}
 	}
-						  
-#if GNOME2_CONVERSION_COMPLETE
-	gnome_uri_list_free_strings (names);
-#endif
+
+	nautilus_icon_dnd_uri_list_free_strings (names);
 
 	gtk_drag_finish (context, TRUE, FALSE, time);
 }
@@ -522,7 +519,7 @@ editable_key_press_callback (GtkObject *object,
 	 * you can't move through the text a character at a
 	 * time. Seems like a bad idea.
 	 */
-	if (event->keyval == GDK_Right
+	if ((event->keyval == GDK_Right || event->keyval == GDK_End)
 	    && gtk_editable_get_selection_bounds (editable, NULL, NULL)) {
 		set_position_and_selection_to_end (editable);
 	}
@@ -671,9 +668,9 @@ nautilus_location_bar_init (NautilusLocationBar *bar)
 
 	nautilus_entry_set_special_tab_handling (NAUTILUS_ENTRY (entry), TRUE);
 	
-	gtk_signal_connect_object (GTK_OBJECT (entry), "activate",
-				   G_CALLBACK (nautilus_navigation_bar_location_changed),
-				   GTK_OBJECT (bar));
+	g_signal_connect_swapped (entry, "activate",
+				  G_CALLBACK (nautilus_navigation_bar_location_changed),
+				  bar);
 
 #if GNOME2_CONVERSION_COMPLETE
 	/* The callback uses the marshal interface directly
@@ -695,9 +692,9 @@ nautilus_location_bar_init (NautilusLocationBar *bar)
 			     GDK_BUTTON1_MASK | GDK_BUTTON3_MASK,
 			     drag_types, G_N_ELEMENTS (drag_types),
 			     GDK_ACTION_LINK);
-	gtk_signal_connect  (GTK_OBJECT (event_box), "drag_data_get",
-			     G_CALLBACK (drag_data_get_callback),
-			     bar);
+	g_signal_connect  (event_box, "drag_data_get",
+			   G_CALLBACK (drag_data_get_callback),
+			   bar);
 
 	/* Drag dest. */
 	gtk_drag_dest_set  (GTK_WIDGET (bar),
