@@ -33,6 +33,7 @@
 #include "nautilus-window-private.h"
 #include "nautilus-window.h"
 #include <bonobo/bonobo-control.h>
+#include <bonobo/bonobo-property-bag.h>
 #include <bonobo/bonobo-exception.h>
 #include <bonobo/bonobo-moniker-util.h>
 #include <bonobo/bonobo-ui-util.h>
@@ -54,6 +55,11 @@
  */
 #include "nautilus-desktop-window.h"
 
+enum {
+	TOOLBAR_ITEM_STYLE_PROP,
+	TOOLBAR_ITEM_ORIENTATION_PROP
+};
+
 static void
 activate_back_or_forward_menu_item (GtkMenuItem *menu_item, 
 				    NautilusWindow *window,
@@ -64,7 +70,7 @@ activate_back_or_forward_menu_item (GtkMenuItem *menu_item,
 	g_assert (GTK_IS_MENU_ITEM (menu_item));
 	g_assert (NAUTILUS_IS_WINDOW (window));
 
-	index = GPOINTER_TO_INT (gtk_object_get_user_data (GTK_OBJECT (menu_item)));
+	index = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (menu_item), "user_data"));
 	nautilus_window_back_or_forward (window, back, index);
 }
 
@@ -97,17 +103,17 @@ create_back_or_forward_menu (NautilusWindow *window, gboolean back)
 	while (list_link != NULL)
 	{
 		menu_item = nautilus_bookmark_menu_item_new (NAUTILUS_BOOKMARK (list_link->data));		
-		gtk_object_set_user_data (GTK_OBJECT (menu_item), GINT_TO_POINTER (index));
+		g_object_set_data (G_OBJECT (menu_item), "user_data", GINT_TO_POINTER (index));
 		gtk_widget_show (GTK_WIDGET (menu_item));
-  		gtk_signal_connect
-			(GTK_OBJECT(menu_item), 
+  		g_signal_connect
+			(menu_item,
 			 "activate",
 			 back
 			 ? G_CALLBACK (activate_back_menu_item_callback)
 			 : G_CALLBACK (activate_forward_menu_item_callback),
 			 window);
 		
-		gtk_menu_append (menu, menu_item);
+		gtk_menu_shell_append (GTK_MENU_SHELL (menu), menu_item);
 		list_link = g_list_next (list_link);
 		++index;
 	}
@@ -218,14 +224,12 @@ static void
 set_up_standard_bonobo_button (NautilusWindow *window, 
 			       const char *item_path, 
 			       const char *icon_name,
-			       gboolean is_custom)
+			       const char *stock_item_fallback)
 {
 	char *file_name;
 
-	file_name = get_file_name_from_icon_name (icon_name, is_custom);
+	file_name = get_file_name_from_icon_name (icon_name, (stock_item_fallback == NULL));
 		
-	nautilus_window_ui_freeze (window);
-
 	/* set up the toolbar component with the new image */
 	bonobo_ui_component_set_prop (window->details->shell_ui, 
 				      item_path,
@@ -235,75 +239,47 @@ set_up_standard_bonobo_button (NautilusWindow *window,
 	bonobo_ui_component_set_prop (window->details->shell_ui, 
 				      item_path,
 				      "pixname",
-				      file_name == NULL ? icon_name : file_name,
+				      file_name == NULL ? stock_item_fallback : file_name,
 			      	      NULL);
 
 	g_free (file_name);
-
-	nautilus_window_ui_thaw (window);
-}
-
-static GdkPixbuf *
-get_pixbuf_for_xml_node (NautilusWindow *window, const char *node_path)
-{
-	BonoboUINode *node;
-	GdkPixbuf *pixbuf;
-
-	node = bonobo_ui_component_get_tree (window->details->shell_ui, node_path, FALSE, NULL);
-#if GNOME2_CONVERSION_COMPLETE
-	pixbuf = bonobo_ui_util_xml_get_icon_pixbuf (node, FALSE);
-#else
-	pixbuf = NULL;
-#endif
-	bonobo_ui_node_free (node);
-
-	return pixbuf;
 }
 
 /* Use only for toolbar buttons that had to be explicitly created so they
  * could have behaviors not present in standard Bonobo toolbar buttons.
  */
 static void
-set_up_special_bonobo_button (NautilusWindow *window,
+set_up_special_bonobo_button (NautilusWindow            *window,
 			      BonoboUIToolbarButtonItem *item,
-			      const char *control_path,
-			      const char *icon_name)
+			      const char                *control_path,
+			      const char                *icon_name,
+			      const char                *stock_item_fallback)
 {
 	char *icon_file_name;
-	GdkPixbuf *pixbuf;	
+	GtkWidget *image;
+	GtkStockItem stock_item;
+
+	image = NULL;
 
 	icon_file_name = get_file_name_from_icon_name (icon_name, FALSE);
 
 	if (icon_file_name == NULL) {
-		pixbuf = get_pixbuf_for_xml_node (window, control_path);
+		if (gtk_stock_lookup (stock_item_fallback, &stock_item)) {
+			image = gtk_image_new_from_stock (stock_item_fallback, 
+							  GTK_ICON_SIZE_BUTTON);
+		}
 	} else {
-		pixbuf = gdk_pixbuf_new_from_file (icon_file_name, NULL);
+		image = gtk_image_new_from_file (icon_file_name);
 		g_free (icon_file_name);
 	}
+
+	if (image == NULL) {
+		return;
+	}
 	
-	nautilus_window_ui_freeze (window);
-
-	bonobo_ui_toolbar_button_item_set_image (item, gtk_image_new_from_pixbuf (pixbuf));
-	g_object_unref (pixbuf);
-
-#if GNOME2_CONVERSION_COMPLETE
-	/* FIXME bugzilla.gnome.org 45005:
-	 * Setting the style here accounts for the preference, but does not
-	 * account for a hard-wired toolbar style or later changes in style
-	 * (such as if the toolbar is detached and made vertical). There
-	 * is currently no Bonobo API to support matching the style properly.
-	 */
-	bonobo_ui_toolbar_item_set_style 
-		(BONOBO_UI_TOOLBAR_ITEM (item),
-		 gnome_preferences_get_toolbar_labels ()
-		 	? BONOBO_UI_TOOLBAR_ITEM_STYLE_ICON_AND_TEXT_VERTICAL
-		 	: BONOBO_UI_TOOLBAR_ITEM_STYLE_ICON_ONLY);
-#endif
-
-	nautilus_window_ui_thaw (window);
+	bonobo_ui_toolbar_button_item_set_image (item, image);
 }			      
 
-
 static void
 set_up_toolbar_images (NautilusWindow *window)
 {
@@ -311,15 +287,17 @@ set_up_toolbar_images (NautilusWindow *window)
 
 	bonobo_ui_component_freeze (window->details->shell_ui, NULL);
 
-	set_up_special_bonobo_button (window, window->details->back_button_item, "/Toolbar/BackWrapper", "Back");
-	set_up_special_bonobo_button (window, window->details->forward_button_item, "/Toolbar/ForwardWrapper", "Forward");
+	set_up_special_bonobo_button (window, window->details->back_button_item, 
+				      "/Toolbar/BackWrapper", "Back", GTK_STOCK_GO_BACK);
+	set_up_special_bonobo_button (window, window->details->forward_button_item, 
+				      "/Toolbar/ForwardWrapper", "Forward", GTK_STOCK_GO_FORWARD);
 	
-	set_up_standard_bonobo_button (window, "/Toolbar/Up", "Up", FALSE);
-	set_up_standard_bonobo_button (window, "/Toolbar/Home", "Home", FALSE);
-	set_up_standard_bonobo_button (window, "/Toolbar/Reload", "Refresh", FALSE);
-	set_up_standard_bonobo_button (window, "/Toolbar/Toggle Find Mode", "Search", FALSE);
-	set_up_standard_bonobo_button (window, "/Toolbar/Go to Web Search", "SearchWeb", TRUE);
-	set_up_standard_bonobo_button (window, "/Toolbar/Stop", "Stop", FALSE);
+	set_up_standard_bonobo_button (window, "/Toolbar/Up", "Up", GTK_STOCK_GO_UP);
+	set_up_standard_bonobo_button (window, "/Toolbar/Home", "Home", GTK_STOCK_HOME);
+	set_up_standard_bonobo_button (window, "/Toolbar/Reload", "Refresh", GTK_STOCK_REFRESH);
+	set_up_standard_bonobo_button (window, "/Toolbar/Toggle Find Mode", "Search", GTK_STOCK_FIND);
+	set_up_standard_bonobo_button (window, "/Toolbar/Go to Web Search", "SearchWeb", NULL);
+	set_up_standard_bonobo_button (window, "/Toolbar/Stop", "Stop", GTK_STOCK_STOP);
 
 	bonobo_ui_component_thaw (window->details->shell_ui, NULL);
 
@@ -345,26 +323,45 @@ theme_changed_callback (gpointer callback_data)
 }
 
 static void
-set_widget_for_bonobo_control (NautilusWindow *window,
-			       GtkWidget *widget,
-			       const char *control_path)
+back_or_forward_toolbar_item_property_set_cb (BonoboPropertyBag *bag,
+					      const BonoboArg   *arg,
+					      guint              arg_id,
+					      CORBA_Environment *ev,
+					      gpointer           user_data)
 {
-	BonoboControl *wrapper;
+	BonoboControl *control;
+	BonoboUIToolbarItem *item;
+	GtkOrientation orientation;
+	BonoboUIToolbarItemStyle style;
 
-	wrapper = bonobo_control_new (widget);
-	bonobo_ui_component_object_set (window->details->shell_ui,
-					control_path,
-					bonobo_object_corba_objref (BONOBO_OBJECT (wrapper)),
-					NULL);
-	bonobo_object_unref (BONOBO_OBJECT (wrapper));
+	control = BONOBO_CONTROL (user_data);
+	item = BONOBO_UI_TOOLBAR_ITEM (
+		bonobo_control_get_widget (control));
+
+	switch (arg_id) {
+	case TOOLBAR_ITEM_ORIENTATION_PROP:
+		orientation = BONOBO_ARG_GET_INT (arg);
+		bonobo_ui_toolbar_item_set_orientation (item, orientation);
+
+		if (GTK_WIDGET (item)->parent) {
+			gtk_widget_queue_resize (GTK_WIDGET (item)->parent);
+		}
+		break;
+	case TOOLBAR_ITEM_STYLE_PROP:
+		style = BONOBO_ARG_GET_INT (arg);
+		bonobo_ui_toolbar_item_set_style (item, style);
+		break;
+	}
 }
 
 static BonoboUIToolbarButtonItem *
-set_up_back_or_forward_toolbar_item (NautilusWindow *window, 
-				      const char *label, 
-				      const char *control_path)
+create_back_or_forward_toolbar_item (NautilusWindow *window, 
+				     const char     *label, 
+				     const char     *control_path)
 {
 	BonoboUIToolbarButtonItem *item;
+	BonoboPropertyBag *pb;
+	BonoboControl *wrapper;
 	GtkButton *button;
 
 	item = BONOBO_UI_TOOLBAR_BUTTON_ITEM 
@@ -373,18 +370,39 @@ set_up_back_or_forward_toolbar_item (NautilusWindow *window,
 
 	button = bonobo_ui_toolbar_button_item_get_button_widget (item);
 	g_signal_connect (button,
-			    "button_press_event",
-			    G_CALLBACK (back_or_forward_button_pressed_callback),
-			    window);
+			  "button_press_event",
+			  G_CALLBACK (back_or_forward_button_pressed_callback),
+			  window);
 	g_signal_connect (button,
-			    "clicked",
-			    G_CALLBACK (back_or_forward_button_clicked_callback),
-			    window);
-	set_widget_for_bonobo_control (window, GTK_WIDGET (item), control_path);
+			  "clicked",
+			  G_CALLBACK (back_or_forward_button_clicked_callback),
+			  window);
+
+	wrapper = bonobo_control_new (GTK_WIDGET (item));
+	pb = bonobo_property_bag_new (
+		NULL, back_or_forward_toolbar_item_property_set_cb, wrapper);
+	bonobo_property_bag_add (pb, "style",
+				 TOOLBAR_ITEM_STYLE_PROP,
+				 BONOBO_ARG_INT, NULL,
+				 _("Toolbar item style"),
+				 Bonobo_PROPERTY_WRITEABLE);
+	bonobo_property_bag_add (pb, "orientation",
+				 TOOLBAR_ITEM_ORIENTATION_PROP,
+				 BONOBO_ARG_INT, NULL,
+				 _("Toolbar item orientation"),
+				 Bonobo_PROPERTY_WRITEABLE);
+	bonobo_control_set_properties (wrapper, BONOBO_OBJREF (pb), NULL);
+	bonobo_object_unref (BONOBO_OBJECT (pb));
+
+	bonobo_ui_component_object_set (window->details->shell_ui,
+					control_path,
+					BONOBO_OBJREF (wrapper),
+					NULL);
+
+	bonobo_object_unref (BONOBO_OBJECT (wrapper));
 
 	return item;
 }
-			       
 
 void
 nautilus_window_initialize_toolbars (NautilusWindow *window)
@@ -392,7 +410,7 @@ nautilus_window_initialize_toolbars (NautilusWindow *window)
 	CORBA_Environment ev;
 	char *exception_as_text;
 
-	CORBA_exception_init (&ev);
+	nautilus_window_ui_freeze (window);
 
 	/* FIXME bugzilla.gnome.org 41243: 
 	 * We should use inheritance instead of these special cases
@@ -406,27 +424,24 @@ nautilus_window_initialize_toolbars (NautilusWindow *window)
 	 * desktop window.
 	 */
 	if (!NAUTILUS_IS_DESKTOP_WINDOW (window)) {
-		window->throbber = bonobo_get_object ("OAFIID:nautilus_throbber", "IDL:Bonobo/Control:1.0", &ev);
+		CORBA_exception_init (&ev);
+
+		window->details->throbber = bonobo_get_object ("OAFIID:nautilus_throbber", "IDL:Bonobo/Control:1.0", &ev);
 		if (BONOBO_EX (&ev)) {
 			exception_as_text = bonobo_exception_get_text (&ev);
-			g_warning ("Throbber Activation exception '%s'",
-				   exception_as_text);
+			g_warning ("Throbber activation exception '%s'", exception_as_text);
 			g_free (exception_as_text);
-			window->throbber = CORBA_OBJECT_NIL;
+			window->details->throbber = CORBA_OBJECT_NIL;
+		} else if (window->details->throbber != CORBA_OBJECT_NIL) {
+			bonobo_ui_component_object_set (window->details->shell_ui, "/Toolbar/ThrobberWrapper",
+							window->details->throbber, NULL);
 		}
+		CORBA_exception_free (&ev);
 	}
-
-	nautilus_window_ui_freeze (window);
-
-	bonobo_ui_component_object_set (window->details->shell_ui,
-					"/Toolbar/ThrobberWrapper",
-					window->throbber,
-					&ev);
-	CORBA_exception_free (&ev);
 	
-	window->details->back_button_item = set_up_back_or_forward_toolbar_item 
+	window->details->back_button_item = create_back_or_forward_toolbar_item 
 		(window, _("Back"), "/Toolbar/BackWrapper");
-	window->details->forward_button_item = set_up_back_or_forward_toolbar_item 
+	window->details->forward_button_item = create_back_or_forward_toolbar_item 
 		(window, _("Forward"), "/Toolbar/ForwardWrapper");
 
 	set_up_toolbar_images (window);
