@@ -28,6 +28,7 @@
 /* nautilus-window.c: Implementation of the main window object */
 
 #include <config.h>
+#include <unistd.h>
 #include "nautilus-window-private.h"
 
 #include "nautilus-application.h"
@@ -40,8 +41,9 @@
 #include "nautilus-zoom-control.h"
 #include <X11/Xatom.h>
 #include <bonobo/bonobo-exception.h>
+#include <bonobo/bonobo-property-bag-client.h>
 #include <bonobo/bonobo-ui-util.h>
-#include <ctype.h>
+#include <eel/eel-debug.h>
 #include <eel/eel-gdk-extensions.h>
 #include <eel/eel-gdk-pixbuf-extensions.h>
 #include <eel/eel-generous-bin.h>
@@ -58,7 +60,6 @@
 #include <gtk/gtkvbox.h>
 #include <libgnome/gnome-i18n.h>
 #include <libgnome/gnome-util.h>
-#include <libgnomeui/gnome-geometry.h>
 #include <libgnomeui/gnome-messagebox.h>
 #include <libgnomeui/gnome-uidefs.h>
 #include <libgnomeui/gnome-window-icon.h>
@@ -103,7 +104,7 @@
 #define NAUTILUS_MENU_PATH_EXTRA_VIEWER_PLACEHOLDER	"/menu/View/View Choices/Extra Viewer"
 #define NAUTILUS_MENU_PATH_BEFORE_SHORT_LIST_SEPARATOR  "/menu/View/View Choices/Before Short List"
 #define NAUTILUS_MENU_PATH_SHORT_LIST_PLACEHOLDER  	"/menu/View/View Choices/Short List"
-#define NAUTILUS_MENU_PATH_AFTER_SHORT_LIST_SEPARATOR   "/menu/View/View Choices/Before Short List"
+#define NAUTILUS_MENU_PATH_AFTER_SHORT_LIST_SEPARATOR   "/menu/View/View Choices/After Short List"
 
 enum {
 	ARG_0,
@@ -116,15 +117,19 @@ static GList *history_list = NULL;
 static GdkPixmap *mini_icon_pixmap;
 static GdkBitmap *mini_icon_mask;
 
-static void nautilus_window_initialize_class          (NautilusWindowClass *klass);
-static void nautilus_window_initialize                (NautilusWindow      *window);
+static void nautilus_window_class_init          (NautilusWindowClass *klass);
+static void nautilus_window_init                (NautilusWindow      *window);
 static void nautilus_window_destroy                   (GtkObject           *object);
-static void nautilus_window_set_arg                   (GtkObject           *object,
-						       GtkArg              *arg,
-						       guint                arg_id);
-static void nautilus_window_get_arg                   (GtkObject           *object,
-						       GtkArg              *arg,
-						       guint                arg_id);
+static void nautilus_window_set_property              (GObject             *object,
+						       guint                arg_id,
+						       const GValue        *value,
+						       GParamSpec          *pspec);
+
+static void nautilus_window_get_property              (GObject           *object,
+						       guint              arg_id,
+						       GValue            *value,
+						       GParamSpec        *pspec);
+
 static void nautilus_window_size_request              (GtkWidget           *widget,
 						       GtkRequisition      *requisition);
 static void nautilus_window_realize                   (GtkWidget           *widget);
@@ -135,45 +140,57 @@ static void nautilus_window_unrealize                 (GtkWidget           *widg
 static void cancel_view_as_callback                   (NautilusWindow      *window);
 static void real_add_current_location_to_history_list (NautilusWindow      *window);
 
-EEL_DEFINE_CLASS_BOILERPLATE (NautilusWindow,
+EEL_CLASS_BOILERPLATE (NautilusWindow,
 			      nautilus_window,
 			      BONOBO_TYPE_WINDOW)
 
 static void
 unref_mini_icon (void)
 {
-	gdk_pixmap_unref (mini_icon_pixmap);
+	g_object_unref (mini_icon_pixmap);
 	if (mini_icon_mask != NULL) {
-		gdk_bitmap_unref (mini_icon_mask);
+		g_object_unref (mini_icon_mask);
 	}
 }
 
 static void
-nautilus_window_initialize_class (NautilusWindowClass *klass)
+nautilus_window_class_init (NautilusWindowClass *klass)
 {
+	GObjectClass   *gobject_class;
 	GtkObjectClass *object_class;
 	GtkWidgetClass *widget_class;
 	char *filename;
 	GdkPixbuf *pixbuf;
+	GList *icons;
+	guint i;
+	char *icon_filenames[] = { "nautilus-mini-logo.png", "nautilus-launch-icon.png" };
 	
+	gobject_class = (GObjectClass *) klass;
 	object_class = (GtkObjectClass *) klass;
 	widget_class = (GtkWidgetClass *) klass;
 
 	object_class->destroy = nautilus_window_destroy;
-	object_class->get_arg = nautilus_window_get_arg;
-	object_class->set_arg = nautilus_window_set_arg;
+	gobject_class->get_property = nautilus_window_get_property;
+	gobject_class->set_property = nautilus_window_set_property;
 	
 	widget_class->show = nautilus_window_show;
 	widget_class->unrealize = nautilus_window_unrealize;
 	
-	gtk_object_add_arg_type ("NautilusWindow::app_id",
-				 GTK_TYPE_STRING,
-				 GTK_ARG_READWRITE | GTK_ARG_CONSTRUCT,
-				 ARG_APP_ID);
-	gtk_object_add_arg_type ("NautilusWindow::app",
-				 GTK_TYPE_OBJECT,
-				 GTK_ARG_READWRITE | GTK_ARG_CONSTRUCT,
-				 ARG_APP);
+	g_object_class_install_property (gobject_class,
+					 ARG_APP_ID,
+					 g_param_spec_string ("app_id",
+							      _("Application ID"),
+							      _("The application ID of the window."),
+							      NULL,
+							      G_PARAM_READWRITE | G_PARAM_CONSTRUCT));
+
+	g_object_class_install_property (gobject_class,
+					 ARG_APP,
+					 g_param_spec_object ("app",
+							      _("Application"),
+							      _("The NautilusApplication associated with this window."),
+							      NAUTILUS_TYPE_APPLICATION,
+							      G_PARAM_READWRITE | G_PARAM_CONSTRUCT));
 	
 	widget_class->realize = nautilus_window_realize;
 	widget_class->size_request = nautilus_window_size_request;
@@ -181,18 +198,38 @@ nautilus_window_initialize_class (NautilusWindowClass *klass)
 	klass->add_current_location_to_history_list
 		= real_add_current_location_to_history_list;
 
+	/* Load the mini icon for backwards compat */
         filename = nautilus_pixmap_file ("nautilus-mini-logo.png");
         if (filename != NULL) {
-                pixbuf = gdk_pixbuf_new_from_file (filename);
+                pixbuf = gdk_pixbuf_new_from_file (filename, NULL);
                 if (pixbuf != NULL) {
                         gdk_pixbuf_render_pixmap_and_mask
 				(pixbuf, &mini_icon_pixmap, &mini_icon_mask,
 				 EEL_STANDARD_ALPHA_THRESHHOLD);
-			gdk_pixbuf_unref (pixbuf);
-			g_atexit (unref_mini_icon);
+			g_object_unref (pixbuf);
+			eel_debug_call_at_shutdown (unref_mini_icon);
 		}
         	g_free (filename);
 	}
+
+
+	/* Set default icon list for all windows */
+	icons = NULL;
+	for (i = 0; i < G_N_ELEMENTS (icon_filenames); i++) {
+		filename = nautilus_pixmap_file (icon_filenames[i]);
+		if (filename != NULL) {
+			pixbuf = gdk_pixbuf_new_from_file (filename, NULL);
+			if (pixbuf != NULL) {
+				icons = g_list_prepend (icons, pixbuf);
+			}
+			g_free (filename);
+		}
+	}
+	
+	gtk_window_set_default_icon_list (icons);
+	
+	g_list_foreach (icons, (GFunc) g_object_unref, NULL);
+	g_list_free (icons);
 }
 
 static void
@@ -209,11 +246,11 @@ add_sidebar_panel_callback (const char *name,
 	eel_preferences_add_callback_while_alive (preference_key,
 						  sidebar_panels_changed_callback,
 						  callback_data,
-						  GTK_OBJECT (callback_data));
+						  G_OBJECT (callback_data));
 }
 
 static void
-nautilus_window_initialize (NautilusWindow *window)
+nautilus_window_init (NautilusWindow *window)
 {
 	window->details = g_new0 (NautilusWindowDetails, 1);
 
@@ -265,7 +302,7 @@ static inline void
 ui_install_idle_handler (NautilusWindow *window)
 {
 	if (window->details->ui_idle_id == 0) {
-		window->details->ui_idle_id = gtk_idle_add_priority (GTK_PRIORITY_LOW, ui_idle_handler, window);
+		window->details->ui_idle_id = g_idle_add_full (G_PRIORITY_LOW, ui_idle_handler, window, NULL);
 	}
 }
 
@@ -273,7 +310,7 @@ static inline void
 ui_remove_idle_handler (NautilusWindow *window)
 {
 	if (window->details->ui_idle_id != 0) {
-		gtk_idle_remove (window->details->ui_idle_id);
+		g_source_remove (window->details->ui_idle_id);
 		window->details->ui_idle_id = 0;
 	}
 }
@@ -507,88 +544,28 @@ set_initial_window_geometry (NautilusWindow *window)
 	 * is evil. So we choose semi-arbitrary initial and
 	 * minimum widths instead of letting GTK decide.
 	 */
-
+	/* FIXME - the above comment suggests that the size request
+	 * of the content view area is wrong, probably because of
+	 * another stupid set_usize someplace. If someone gets the
+	 * content view area's size request right then we can
+	 * probably remove this broken set_size_request() here.
+	 * - hp@redhat.com
+	 */
+	
 	max_width_for_screen = get_max_forced_width ();
 	max_height_for_screen = get_max_forced_height ();
 
-	gtk_widget_set_usize (GTK_WIDGET (window), 
-			      MIN (NAUTILUS_WINDOW_MIN_WIDTH, 
-			           max_width_for_screen),
-			      MIN (NAUTILUS_WINDOW_MIN_HEIGHT, 
-			           max_height_for_screen));
+	gtk_widget_set_size_request (GTK_WIDGET (window), 
+				     MIN (NAUTILUS_WINDOW_MIN_WIDTH, 
+					  max_width_for_screen),
+				     MIN (NAUTILUS_WINDOW_MIN_HEIGHT, 
+					  max_height_for_screen));
 
 	gtk_window_set_default_size (GTK_WINDOW (window), 
 				     MIN (NAUTILUS_WINDOW_DEFAULT_WIDTH, 
 				          max_width_for_screen), 
 				     MIN (NAUTILUS_WINDOW_DEFAULT_HEIGHT, 
 				          max_height_for_screen));
-
-	gtk_window_set_policy (GTK_WINDOW (window), 
-			       FALSE,  /* don't let window be stretched 
-			                  smaller than usize */
-			       TRUE,   /* do let the window be stretched 
-			                  larger than default size */
-			       FALSE); /* don't shrink the window 
-			                  automatically to fit contents */
-
-}
-
-static void
-menu_bar_no_resize_hack_size_allocate (GtkWidget *widget, GtkAllocation *allocation)
-{
-	/* do nothing */
-}
-
-static void
-menu_bar_no_resize_hack_menu_bar_finder (GtkWidget *child, gpointer data)
-{
-	if (GTK_IS_MENU_BAR (child)) {
-		* (GtkObject **) data = GTK_OBJECT (child);
-	}
-}
-
-/* Since there's only one desktop at a time, we can keep track
- * of our faux-class with a single static.
- */
-static GtkObjectClass *menu_bar_no_resize_hack_class;
-
-static void
-menu_bar_no_resize_hack_class_free (void)
-{
-	g_free (menu_bar_no_resize_hack_class);
-}
-
-/* This call is used to keep the desktop menu bar from resizing.
- * It patches out its class with one where the size_allocate
- * method has been replaced with a no-op.
- */
-static void
-menu_bar_no_resize_hack (NautilusWindow *window)
-{
-	GtkObject *menu_bar;
-	GtkTypeQuery *type_query;
-	
-	menu_bar = NULL;
-	
-	eel_gtk_container_foreach_deep (GTK_CONTAINER (window),
-					     menu_bar_no_resize_hack_menu_bar_finder,
-					     &menu_bar);
-
-	g_return_if_fail (menu_bar != NULL);
-
-	if (menu_bar_no_resize_hack_class == NULL) {
-		g_atexit (menu_bar_no_resize_hack_class_free);
-	}
-	
-	type_query = gtk_type_query (menu_bar->klass->type);
-	g_free (menu_bar_no_resize_hack_class);
-	menu_bar_no_resize_hack_class = g_memdup (menu_bar->klass, type_query->class_size);
-	g_free (type_query);
-	
-	((GtkWidgetClass *) menu_bar_no_resize_hack_class)->size_allocate
-		= menu_bar_no_resize_hack_size_allocate;
-
-	menu_bar->klass = menu_bar_no_resize_hack_class;
 }
 
 static gboolean
@@ -609,14 +586,15 @@ location_change_at_idle_callback (gpointer callback_data)
 	return FALSE;
 }
 
+
 /* handle bonobo events from the throbber -- since they can come in at
    any time right in the middle of things, defer until idle */
 static void 
-throbber_location_change_request_callback (BonoboListener *listener,
-					   char *event_name, 
-					   CORBA_any *arg,
-					   CORBA_Environment *ev,
-					   gpointer callback_data)
+throbber_callback (BonoboListener *listener,
+		   const char *event_name, 
+		   const CORBA_any *arg,
+		   CORBA_Environment *ev,
+		   gpointer callback_data)
 {
 	NautilusWindow *window;
 
@@ -645,7 +623,7 @@ set_dummy_initial_view_as_menu (NautilusWindow *window)
 	new_menu = gtk_menu_new ();
 	menu_item = gtk_menu_item_new_with_label (_("View as..."));
        	gtk_widget_show (menu_item);
-       	gtk_menu_append (GTK_MENU (new_menu), menu_item);
+       	gtk_menu_shell_append (GTK_MENU_SHELL (new_menu), menu_item);
 
         gtk_option_menu_set_menu (GTK_OPTION_MENU (window->view_as_option_menu),
                                   new_menu);
@@ -658,20 +636,20 @@ nautilus_window_constructed (NautilusWindow *window)
 	GtkWidget *view_as_menu_vbox;
   	int sidebar_width;
 	BonoboControl *location_bar_wrapper;
-	EPaned *panel;
 	CORBA_Environment ev;
 	Bonobo_PropertyBag property_bag;
 	
 	/* CORBA and Bonobo setup, which must be done before the location bar setup */
 	window->details->ui_container = bonobo_ui_container_new ();
-	bonobo_ui_container_set_win (window->details->ui_container,
-				     BONOBO_WINDOW (window));
+	bonobo_ui_container_set_engine (window->details->ui_container,
+					bonobo_window_get_ui_engine (BONOBO_WINDOW (window)));
 
 	/* Load the user interface from the XML file. */
 	window->details->shell_ui = bonobo_ui_component_new ("Nautilus Shell");
 	bonobo_ui_component_set_container
 		(window->details->shell_ui,
-		 nautilus_window_get_ui_container (window));
+		 nautilus_window_get_ui_container (window),
+		 NULL);
 
 	nautilus_window_ui_freeze (window);
 
@@ -679,7 +657,7 @@ nautilus_window_constructed (NautilusWindow *window)
 	bonobo_ui_util_set_ui (window->details->shell_ui,
 			       DATADIR,
 			       "nautilus-shell-ui.xml",
-			       "nautilus");
+			       "nautilus", NULL);
 	bonobo_ui_component_thaw (window->details->shell_ui, NULL);
 	
 	/* set up location bar */
@@ -689,11 +667,11 @@ nautilus_window_constructed (NautilusWindow *window)
 	window->navigation_bar = nautilus_switchable_navigation_bar_new (window);
 	gtk_widget_show (GTK_WIDGET (window->navigation_bar));
 
-	gtk_signal_connect (GTK_OBJECT (window->navigation_bar), "location_changed",
-			    navigation_bar_location_changed_callback, window);
+	g_signal_connect (window->navigation_bar, "location_changed",
+			    G_CALLBACK (navigation_bar_location_changed_callback), window);
 
-	gtk_signal_connect (GTK_OBJECT (window->navigation_bar), "mode_changed",
-			    navigation_bar_mode_changed_callback, window);
+	g_signal_connect (window->navigation_bar, "mode_changed",
+			    G_CALLBACK (navigation_bar_mode_changed_callback), window);
 
 	gtk_box_pack_start (GTK_BOX (location_bar_box), window->navigation_bar,
 			    TRUE, TRUE, GNOME_PAD_SMALL);
@@ -717,14 +695,14 @@ nautilus_window_constructed (NautilusWindow *window)
 	 * It gets shown later, if the view-frame contains something zoomable.
 	 */
 	window->zoom_control = nautilus_zoom_control_new ();
-	gtk_signal_connect_object (GTK_OBJECT (window->zoom_control), "zoom_in",
-				   nautilus_window_zoom_in, GTK_OBJECT (window));
-	gtk_signal_connect_object (GTK_OBJECT (window->zoom_control), "zoom_out",
-				   nautilus_window_zoom_out, GTK_OBJECT (window));
-	gtk_signal_connect_object (GTK_OBJECT (window->zoom_control), "zoom_to_level",
-				   nautilus_window_zoom_to_level, GTK_OBJECT (window));
-	gtk_signal_connect_object (GTK_OBJECT (window->zoom_control), "zoom_to_fit",
-				   nautilus_window_zoom_to_fit, GTK_OBJECT (window));
+	g_signal_connect_swapped (window->zoom_control, "zoom_in",
+				  G_CALLBACK (nautilus_window_zoom_in), window);
+	g_signal_connect_swapped (window->zoom_control, "zoom_out",
+				  G_CALLBACK (nautilus_window_zoom_out), window);
+	g_signal_connect_swapped (window->zoom_control, "zoom_to_level",
+				  G_CALLBACK (nautilus_window_zoom_to_level), window);
+	g_signal_connect_swapped (window->zoom_control, "zoom_to_fit",
+				  G_CALLBACK (nautilus_window_zoom_to_fit), window);
 	gtk_box_pack_end (GTK_BOX (location_bar_box), window->zoom_control, FALSE, FALSE, 0);
 	
 	gtk_widget_show (location_bar_box);
@@ -739,12 +717,11 @@ nautilus_window_constructed (NautilusWindow *window)
 		set_initial_window_geometry (window);
 	
 		window->content_hbox = nautilus_horizontal_splitter_new ();
-		panel = E_PANED (window->content_hbox);
 		
 		/* FIXME bugzilla.gnome.org 41245: Saved in pixels instead of in %? */
 		/* FIXME bugzilla.gnome.org 41245: No reality check on the value? */
 		sidebar_width = eel_preferences_get_integer (NAUTILUS_PREFERENCES_SIDEBAR_WIDTH);
-		e_paned_set_position (E_PANED (window->content_hbox), sidebar_width);
+		gtk_paned_set_position (GTK_PANED (window->content_hbox), sidebar_width);
 	}
 	gtk_widget_show (window->content_hbox);
 	bonobo_window_set_contents (BONOBO_WINDOW (window), window->content_hbox);
@@ -757,15 +734,11 @@ nautilus_window_constructed (NautilusWindow *window)
 		/* set up the sidebar */
 		window->sidebar = nautilus_sidebar_new ();
 		gtk_widget_show (GTK_WIDGET (window->sidebar));
-		gtk_signal_connect (GTK_OBJECT (window->sidebar), "location_changed",
-				    go_to_callback, window);
-		e_paned_pack1 (E_PANED (window->content_hbox),
-			       GTK_WIDGET (window->sidebar),
-			       FALSE, TRUE);
-#if 0
-		bonobo_ui_engine_add_sync (bonobo_window_get_ui_engine (BONOBO_WINDOW (window)),
-					   sidebar_sync);
-#endif
+		g_signal_connect (window->sidebar, "location_changed",
+				    G_CALLBACK (go_to_callback), window);
+		gtk_paned_pack1 (GTK_PANED (window->content_hbox),
+				 GTK_WIDGET (window->sidebar),
+				 FALSE, TRUE);
 	}
 	
 	bonobo_ui_component_freeze (window->details->shell_ui, NULL);
@@ -783,19 +756,13 @@ nautilus_window_constructed (NautilusWindow *window)
 					    STATUS_BAR_PATH, TRUE);
 		nautilus_bonobo_set_hidden (window->details->shell_ui,
 					    MENU_BAR_PATH, TRUE);
-
-		/* FIXME bugzilla.gnome.org 44752:
-		 * If we ever get the unsigned math errors in
-		 * gtk_menu_item_size_allocate fixed this can be removed.
-		 */
-		menu_bar_no_resize_hack (window);
 	}
 
 	/* Wrap the location bar in a control and set it up. */
 	location_bar_wrapper = bonobo_control_new (location_bar_box);
 	bonobo_ui_component_object_set (window->details->shell_ui,
 					"/Location Bar/Wrapper",
-					bonobo_object_corba_objref (BONOBO_OBJECT (location_bar_wrapper)),
+					BONOBO_OBJREF (location_bar_wrapper),
 					NULL);
 	bonobo_ui_component_thaw (window->details->shell_ui, NULL);
 	bonobo_object_unref (BONOBO_OBJECT (location_bar_wrapper));
@@ -808,14 +775,15 @@ nautilus_window_constructed (NautilusWindow *window)
 	window->details->ui_pending_initialize_menus_part_2 = TRUE;
 
 	/* watch for throbber location changes, too */
-	if (window->throbber != CORBA_OBJECT_NIL) {
+	if (window->details->throbber != CORBA_OBJECT_NIL) {
 		CORBA_exception_init (&ev);
-		property_bag = Bonobo_Control_getProperties (window->throbber, &ev);
+		property_bag = Bonobo_Control_getProperties (window->details->throbber, &ev);
 		if (!BONOBO_EX (&ev) && property_bag != CORBA_OBJECT_NIL) {
-			window->details->throbber_location_change_request_listener_id =
-				bonobo_event_source_client_add_listener
-				(property_bag, throbber_location_change_request_callback, 
-				 "Bonobo/Property:change:location", NULL, window); 
+			window->details->throbber_listener =
+				bonobo_event_source_client_add_listener_full
+				(property_bag,
+				 g_cclosure_new (G_CALLBACK (throbber_callback), window, NULL), 
+				 "Bonobo/Property:change:location", NULL); 
 			bonobo_object_release_unref (property_bag, NULL);	
 		}
 		CORBA_exception_free (&ev);
@@ -829,7 +797,7 @@ nautilus_window_constructed (NautilusWindow *window)
 	nautilus_window_allow_stop (window, FALSE);
 
 	/* Set up undo manager */
-	nautilus_undo_manager_attach (window->application->undo_manager, GTK_OBJECT (window));	
+	nautilus_undo_manager_attach (window->application->undo_manager, G_OBJECT (window));	
 
 	/* Set up the sidebar panels. */
 	update_sidebar_panels_from_preferences (window);
@@ -841,9 +809,10 @@ nautilus_window_constructed (NautilusWindow *window)
 }
 
 static void
-nautilus_window_set_arg (GtkObject *object,
-			 GtkArg *arg,
-			 guint arg_id)
+nautilus_window_set_property (GObject *object,
+			      guint arg_id,
+			      const GValue *value,
+			      GParamSpec *pspec)
 {
 	char *old_name;
 	NautilusWindow *window;
@@ -852,11 +821,11 @@ nautilus_window_set_arg (GtkObject *object,
 	
 	switch (arg_id) {
 	case ARG_APP_ID:
-		if (GTK_VALUE_STRING (*arg) == NULL) {
+		if (g_value_get_string (value) == NULL) {
 			return;
 		}
 		old_name = bonobo_window_get_name (BONOBO_WINDOW (window));
-		bonobo_window_set_name (BONOBO_WINDOW (window), GTK_VALUE_STRING (*arg));
+		bonobo_window_set_name (BONOBO_WINDOW (window), g_value_get_string (value));
 		/* This hack of using the time when the name first
 		 * goes non-NULL to be window-constructed time is
 		 * completely lame. But it works, so for now we leave
@@ -868,22 +837,25 @@ nautilus_window_set_arg (GtkObject *object,
 		g_free (old_name);
 		break;
 	case ARG_APP:
-		window->application = NAUTILUS_APPLICATION (GTK_VALUE_OBJECT (*arg));
+		window->application = NAUTILUS_APPLICATION (g_value_get_object (value));
 		break;
 	}
 }
 
 static void
-nautilus_window_get_arg (GtkObject *object,
-			 GtkArg *arg,
-			 guint arg_id)
+nautilus_window_get_property (GObject *object,
+			      guint arg_id,
+			      GValue *value,
+			      GParamSpec *pspec)
 {
 	switch (arg_id) {
 	case ARG_APP_ID:
-		GTK_VALUE_STRING (*arg) = bonobo_window_get_name (BONOBO_WINDOW (object));
+		g_value_set_string_take_ownership (
+			value,
+			bonobo_window_get_name (BONOBO_WINDOW (object)));
 		break;
 	case ARG_APP:
-		GTK_VALUE_OBJECT (*arg) = GTK_OBJECT (NAUTILUS_WINDOW (object)->application);
+		g_value_set_object (value, NAUTILUS_WINDOW (object)->application);
 		break;
 	}
 }
@@ -911,21 +883,25 @@ nautilus_window_unrealize (GtkWidget *widget)
 	/* Get rid of the throbber explicitly before it self-destructs
 	 * (which it will do when the control frame goes away.
 	 */
-	if (window->throbber != CORBA_OBJECT_NIL) {
-		CORBA_exception_init (&ev);
-		property_bag = Bonobo_Control_getProperties (window->throbber, &ev);
-		if (!BONOBO_EX (&ev) && property_bag != CORBA_OBJECT_NIL) {	
-			bonobo_event_source_client_remove_listener
-				(property_bag,
-				 window->details->throbber_location_change_request_listener_id,
-				 &ev);
-			bonobo_object_release_unref (property_bag, NULL);	
+	if (window->details->throbber != CORBA_OBJECT_NIL) {
+		if (window->details->throbber_listener != CORBA_OBJECT_NIL) {
+			CORBA_exception_init (&ev);
+
+			property_bag = Bonobo_Control_getProperties (window->details->throbber, &ev);
+			if (!BONOBO_EX (&ev) && property_bag != CORBA_OBJECT_NIL) {	
+				bonobo_event_source_client_remove_listener
+					(property_bag, window->details->throbber_listener, &ev);
+				bonobo_object_release_unref (property_bag, &ev);
+			}
+
+			CORBA_Object_release (window->details->throbber_listener, &ev);
+			window->details->throbber_listener = CORBA_OBJECT_NIL;
+
+			CORBA_exception_free (&ev);
 		}
-		CORBA_exception_free (&ev);
 
-		bonobo_object_release_unref (window->throbber, NULL);
-
-		window->throbber = CORBA_OBJECT_NIL;
+		bonobo_object_release_unref (window->details->throbber, NULL);
+		window->details->throbber = CORBA_OBJECT_NIL;
 	}
 
 	EEL_CALL_PARENT (GTK_WIDGET_CLASS, unrealize, (widget));
@@ -938,63 +914,66 @@ nautilus_window_destroy (GtkObject *object)
 	
 	window = NAUTILUS_WINDOW (object);
 
-	/* Handle the part of destroy that's private to the view
-	 * management.
-	 */
-	nautilus_window_manage_views_destroy (window);
+	if (window->details != NULL) {
+		/* Handle the part of destroy that's private to the view
+		 * management.
+		 */
+		nautilus_window_manage_views_destroy (window);
 
-	/* Get rid of all callbacks. */
-	nautilus_window_set_viewed_file (window, NULL);
-	nautilus_window_remove_bookmarks_menu_callback (window);
-	nautilus_window_remove_go_menu_callback (window);
-	nautilus_window_toolbar_remove_theme_callback (window);
+		/* Get rid of all callbacks. */
+		nautilus_window_set_viewed_file (window, NULL);
+		nautilus_window_remove_bookmarks_menu_callback (window);
+		nautilus_window_remove_go_menu_callback (window);
+		nautilus_window_toolbar_remove_theme_callback (window);
 
-	if (window->details->ui_idle_id != 0) {
-		gtk_idle_remove (window->details->ui_idle_id);
-	}
+		if (window->details->ui_idle_id != 0) {
+			gtk_idle_remove (window->details->ui_idle_id);
+		}
 
-	/* Get rid of all owned objects. */
+		/* Get rid of all owned objects. */
 
-	if (window->details->shell_ui != NULL) {
-		bonobo_ui_component_unset_container (window->details->shell_ui);
-		bonobo_object_unref (BONOBO_OBJECT (window->details->shell_ui));
-	}
+		if (window->details->shell_ui != NULL) {
+			bonobo_ui_component_unset_container (window->details->shell_ui, NULL);
+			bonobo_object_unref (BONOBO_OBJECT (window->details->shell_ui));
+		}
 
-	nautilus_file_unref (window->details->viewed_file);
+		nautilus_file_unref (window->details->viewed_file);
 
-	g_list_free (window->sidebar_panels);
+		g_list_free (window->sidebar_panels);
 
-	free_stored_viewers (window);
+		free_stored_viewers (window);
 	
-	g_free (window->details->location);
-	eel_g_list_free_deep (window->details->selection);
-	eel_g_list_free_deep (window->details->pending_selection);
+		g_free (window->details->location);
+		eel_g_list_free_deep (window->details->selection);
+		eel_g_list_free_deep (window->details->pending_selection);
 
-	nautilus_window_clear_back_list (window);
-	nautilus_window_clear_forward_list (window);
+		nautilus_window_clear_back_list (window);
+		nautilus_window_clear_forward_list (window);
 
-	if (window->current_location_bookmark != NULL) {
-		gtk_object_unref (GTK_OBJECT (window->current_location_bookmark));
-	}
-	if (window->last_location_bookmark != NULL) {
-		gtk_object_unref (GTK_OBJECT (window->last_location_bookmark));
-	}
+		if (window->current_location_bookmark != NULL) {
+			g_object_unref (window->current_location_bookmark);
+		}
+		if (window->last_location_bookmark != NULL) {
+			g_object_unref (window->last_location_bookmark);
+		}
 	
-	if (window->status_bar_clear_id != 0) {
-		g_source_remove (window->status_bar_clear_id);
-	}
+		if (window->status_bar_clear_id != 0) {
+			g_source_remove (window->status_bar_clear_id);
+		}
 
-	if (window->details->ui_container != NULL) {
-		bonobo_object_unref (BONOBO_OBJECT (window->details->ui_container));
-	}
+		if (window->details->ui_container != NULL) {
+			bonobo_object_unref (BONOBO_OBJECT (window->details->ui_container));
+		}
 
-	if (window->details->location_change_at_idle_id != 0) {
-		gtk_idle_remove (window->details->location_change_at_idle_id);
-	}
+		if (window->details->location_change_at_idle_id != 0) {
+			gtk_idle_remove (window->details->location_change_at_idle_id);
+		}
 
-	g_free (window->details->title);
+		g_free (window->details->title);
 	
-	g_free (window->details);
+		g_free (window->details);
+		window->details = NULL;
+	}
 
 	EEL_CALL_PARENT (GTK_OBJECT_CLASS, destroy, (object));
 }
@@ -1007,7 +986,8 @@ nautilus_window_save_geometry (NautilusWindow *window)
         g_return_if_fail (NAUTILUS_IS_WINDOW (window));
 	g_return_if_fail (GTK_WIDGET_VISIBLE (window));
 
-        geometry_string = gnome_geometry_string (GTK_WIDGET (window)->window);
+        geometry_string = eel_gtk_window_get_geometry_string (GTK_WINDOW (window));
+
 	nautilus_file_set_metadata (window->details->viewed_file,
 				    NAUTILUS_METADATA_KEY_WINDOW_GEOMETRY,
 				    NULL,
@@ -1041,9 +1021,9 @@ nautilus_window_update_launcher (GdkWindow *window)
 	/* Set a property on the root window to the time of day in seconds.
 	 * The launcher will monitor the root window for this property change
 	 * to update its launching state */
-	gdk_property_change (GDK_ROOT_PARENT (),
+	gdk_property_change (gdk_get_default_root_window (),
 			     gdk_atom_intern ("_NAUTILUS_LAST_WINDOW_REALIZE_TIME", FALSE),
-			     XA_CARDINAL,
+			     gdk_x11_xatom_to_atom (XA_CARDINAL),
 			     32,
 			     PropModeReplace,
 			     (guchar *) &tmp.tv_sec,
@@ -1053,8 +1033,6 @@ nautilus_window_update_launcher (GdkWindow *window)
 static void
 nautilus_window_realize (GtkWidget *widget)
 {
-	char *filename;
-
         /* Create our GdkWindow */
 	EEL_CALL_PARENT (GTK_WIDGET_CLASS, realize, (widget));
 
@@ -1063,14 +1041,6 @@ nautilus_window_realize (GtkWidget *widget)
 		eel_set_mini_icon (widget->window, mini_icon_pixmap, mini_icon_mask);
 	}
 
-	/* Set the maxi icon */
-	filename = gnome_pixmap_file ("nautilus-launch-icon.png");
-	if (filename != NULL) {
-		gnome_window_icon_set_from_file (GTK_WINDOW (widget),
-						 filename);
-		g_free (filename);
-	}
-
 	/* Notify the launcher that our window has been realized */
 	nautilus_window_update_launcher (widget->window);
 }
@@ -1181,10 +1151,10 @@ view_as_menu_switch_views_callback (GtkWidget *widget, gpointer data)
 
         window = NAUTILUS_WINDOW (data);
 
-        if (GPOINTER_TO_INT (gtk_object_get_data (GTK_OBJECT (widget), "extra viewer")) == TRUE) {
+        if (GPOINTER_TO_INT (g_object_get_data (G_OBJECT (widget), "extra viewer")) == TRUE) {
         	activate_extra_viewer (window);
         } else {
-		viewer_index = GPOINTER_TO_INT (gtk_object_get_data (GTK_OBJECT (widget), "viewer index"));
+		viewer_index = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (widget), "viewer index"));
 		activate_nth_short_list_item (window, viewer_index);
         }
 }
@@ -1201,12 +1171,12 @@ create_view_as_menu_item (NautilusWindow *window,
 	menu_item = gtk_menu_item_new_with_label (menu_label);
 	g_free (menu_label);
 
-	gtk_signal_connect (GTK_OBJECT (menu_item),
+	g_signal_connect (menu_item,
 			    "activate",
-			    view_as_menu_switch_views_callback, 
+			    G_CALLBACK (view_as_menu_switch_views_callback),
 			    window);
 
-	gtk_object_set_data (GTK_OBJECT (menu_item),
+	g_object_set_data (G_OBJECT (menu_item),
 			     "viewer index",
 			     GINT_TO_POINTER (index));
 
@@ -1305,15 +1275,15 @@ update_extra_viewer_in_view_as_menus (NautilusWindow *window,
 		}
 	} else {
 		if (id != NULL) {
-			gtk_menu_prepend (GTK_MENU (menu), new_gtk_separator ());
+			gtk_menu_shell_prepend (GTK_MENU_SHELL (menu), new_gtk_separator ());
 		}
 	}
 
 	/* Add new menu item. */
 	if (id != NULL) {
 		new_menu_item = create_view_as_menu_item (window, window->details->extra_viewer, 0);
-		gtk_object_set_data (GTK_OBJECT (new_menu_item), "extra viewer", GINT_TO_POINTER (TRUE));
-		gtk_menu_prepend (GTK_MENU (menu), new_menu_item);
+		g_object_set_data (G_OBJECT (new_menu_item), "extra viewer", GINT_TO_POINTER (TRUE));
+		gtk_menu_shell_prepend (GTK_MENU_SHELL (menu), new_menu_item);
 	}
 
 	gtk_option_menu_set_menu (GTK_OPTION_MENU (window->view_as_option_menu), menu);
@@ -1519,7 +1489,7 @@ load_view_as_menus_callback (NautilusFile *file,
         	 * historical and technical reasons.
         	 */
                 menu_item = create_view_as_menu_item (window, node->data, index);
-                gtk_menu_append (GTK_MENU (new_menu), menu_item);
+                gtk_menu_shell_append (GTK_MENU_SHELL (new_menu), menu_item);
 
 		/* Menu item in View menu. */
                 add_view_as_bonobo_menu_item (window, 
@@ -1530,7 +1500,7 @@ load_view_as_menus_callback (NautilusFile *file,
 
         /* Add/Show separator before "View as..." if there are any other viewers in menu. */
         if (window->details->short_list_viewers != NULL) {
-	        gtk_menu_append (GTK_MENU (new_menu), new_gtk_separator ());
+	        gtk_menu_shell_append (GTK_MENU_SHELL (new_menu), new_gtk_separator ());
         }
         nautilus_bonobo_set_hidden (window->details->shell_ui,
         			    NAUTILUS_MENU_PATH_AFTER_SHORT_LIST_SEPARATOR, 
@@ -1538,12 +1508,12 @@ load_view_as_menus_callback (NautilusFile *file,
 
 	/* Add "View as..." extra bonus choice. */
        	menu_item = gtk_menu_item_new_with_label (_("View as..."));
-        gtk_signal_connect (GTK_OBJECT (menu_item),
+        g_signal_connect (menu_item,
         		    "activate",
-        		    view_as_menu_choose_view_callback,
+        		    G_CALLBACK (view_as_menu_choose_view_callback),
         		    window);
        	gtk_widget_show (menu_item);
-       	gtk_menu_append (GTK_MENU (new_menu), menu_item);
+       	gtk_menu_shell_append (GTK_MENU_SHELL (new_menu), menu_item);
 
         /* We create and attach a new menu here because adding/removing
          * items from existing menu screws up the size of the option menu.
@@ -1771,14 +1741,19 @@ nautilus_window_allow_stop (NautilusWindow *window, gboolean allow)
 	
 	nautilus_window_ui_freeze (window);
 
+	if (allow)
+		access ("nautilus-throbber: start", 0);
+	else
+		access ("nautilus-throbber: stop", 0);
+
 	nautilus_bonobo_set_sensitive (window->details->shell_ui,
 				       NAUTILUS_COMMAND_STOP, allow);
 
-	if (window->throbber != CORBA_OBJECT_NIL) {
+	if (window->details->throbber != CORBA_OBJECT_NIL) {
 		CORBA_exception_init (&ev);
-		property_bag = Bonobo_Control_getProperties (window->throbber, &ev);
+		property_bag = Bonobo_Control_getProperties (window->details->throbber, &ev);
 		if (!BONOBO_EX (&ev) && property_bag != CORBA_OBJECT_NIL) {
-			bonobo_property_bag_client_set_value_gboolean (property_bag, "throbbing", allow, &ev);
+			bonobo_pbclient_set_boolean (property_bag, "throbbing", allow, &ev);
 			bonobo_object_release_unref (property_bag, NULL);
 		}
 		CORBA_exception_free (&ev);
@@ -1790,8 +1765,8 @@ nautilus_window_allow_stop (NautilusWindow *window, gboolean allow)
 void
 nautilus_send_history_list_changed (void)
 {
-	gtk_signal_emit_by_name (nautilus_signaller_get_current (),
-			 	 "history_list_changed");
+	g_signal_emit_by_name (nautilus_signaller_get_current (),
+			       "history_list_changed");
 }
 
 static void
@@ -1821,7 +1796,7 @@ remove_from_history_list (NautilusBookmark *bookmark)
 	/* Remove any older entry for this same item. There can be at most 1. */
 	if (node != NULL) {
 		history_list = g_list_remove_link (history_list, node);
-		gtk_object_unref (node->data);
+		g_object_unref (node->data);
 		g_list_free_1 (node);
 	}
 }
@@ -1833,31 +1808,38 @@ add_to_history_list (NautilusBookmark *bookmark)
 	 * this is not a NautilusWindow function. Perhaps it belongs
 	 * in its own file.
 	 */
+	int i;
+	GList *l, *next;
 	static gboolean free_history_list_is_set_up;
-	int extra_count, index;
 
 	g_return_if_fail (NAUTILUS_IS_BOOKMARK (bookmark));
 
 	if (!free_history_list_is_set_up) {
-		g_atexit (free_history_list);
+		eel_debug_call_at_shutdown (free_history_list);
 		free_history_list_is_set_up = TRUE;
 	}
 
-	gtk_object_ref (GTK_OBJECT (bookmark));
-	remove_from_history_list (bookmark);
-	history_list = g_list_prepend (history_list, bookmark);
+/*	g_warning ("Add to history list '%s' '%s'",
+		   nautilus_bookmark_get_name (bookmark),
+		   nautilus_bookmark_get_uri (bookmark)); */
 
-	extra_count = g_list_length (history_list) - MAX_HISTORY_ITEMS;
-	if (extra_count > 0) {
-		history_list = g_list_reverse (history_list);
-		for (index = 0; index < extra_count; ++index) {
-			gtk_object_unref (history_list->data);
-			history_list = g_list_remove (history_list, history_list->data);
+	if (!history_list ||
+	    nautilus_bookmark_compare_uris (history_list->data, bookmark)) {
+		g_object_ref (bookmark);
+		remove_from_history_list (bookmark);
+		history_list = g_list_prepend (history_list, bookmark);
+
+		for (i = 0, l = history_list; l; l = next) {
+			next = l->next;
+			
+			if (i++ >= MAX_HISTORY_ITEMS) {
+				g_object_unref (l->data);
+				history_list = g_list_delete_link (history_list, l);
+			}
 		}
-		history_list = g_list_reverse (history_list);
-	}
 
-	nautilus_send_history_list_changed ();
+		nautilus_send_history_list_changed ();
+	}
 }
 
 void
@@ -1867,7 +1849,7 @@ nautilus_remove_from_history_list_no_notify (const char *uri)
 
 	bookmark = nautilus_bookmark_new (uri, "");
 	remove_from_history_list (bookmark);
-	gtk_object_unref (GTK_OBJECT (bookmark));
+	g_object_unref (bookmark);
 }
 
 static void
@@ -1950,9 +1932,8 @@ nautilus_window_display_error (NautilusWindow *window, const char *error_msg)
 {
 	GtkWidget *dialog;
 	
-	dialog = gnome_message_box_new (error_msg, GNOME_MESSAGE_BOX_ERROR, _("Close"), NULL);
-	gnome_dialog_set_close (GNOME_DIALOG (dialog), TRUE);
-	gnome_dialog_set_default (GNOME_DIALOG (dialog), 0);
+	dialog = gtk_message_dialog_new (GTK_WINDOW (window), 0, GTK_MESSAGE_ERROR,
+					 GTK_BUTTONS_CLOSE, error_msg, NULL);
 	gtk_widget_show (dialog);
 }
 
@@ -1986,13 +1967,13 @@ nautilus_window_set_content_view_widget (NautilusWindow *window,
 		 * We should use inheritance instead of these special cases
 		 * for the desktop window.
 		 */
-		if (!E_IS_PANED (window->content_hbox)) {
+		if (!GTK_IS_PANED (window->content_hbox)) {
 			gtk_container_add (GTK_CONTAINER (window->content_hbox),
 					   GTK_WIDGET (new_view));
 		} else {
-			e_paned_pack2 (E_PANED (window->content_hbox),
-				       GTK_WIDGET (new_view),
-				       TRUE, TRUE);
+			gtk_paned_pack2 (GTK_PANED (window->content_hbox),
+					 GTK_WIDGET (new_view),
+					 TRUE, TRUE);
 		}
 	}
 
@@ -2127,28 +2108,19 @@ nautilus_window_hide_sidebar (NautilusWindow *window)
 	if (window->sidebar == NULL) {
 		return;
 	}
-	gtk_widget_hide (GTK_WIDGET (window->sidebar));
-	if (window->content_hbox != NULL) {
-		e_paned_set_position (E_PANED (window->content_hbox), 0);
-	}
+	nautilus_horizontal_splitter_collapse
+		(NAUTILUS_HORIZONTAL_SPLITTER (window->content_hbox));
 	nautilus_window_update_show_hide_menu_items (window);
 }
 
 void 
 nautilus_window_show_sidebar (NautilusWindow *window)
 {
-	GtkWidget *widget;
-
 	if (window->sidebar == NULL) {
 		return;
 	}
-	widget = GTK_WIDGET (window->sidebar);
-	gtk_widget_show (widget);
-	if (window->content_hbox != NULL) {
-		e_paned_set_position (E_PANED (window->content_hbox), widget->allocation.width);
-		/* Make sure sidebar is not in collapsed form also */
-		nautilus_horizontal_splitter_expand (NAUTILUS_HORIZONTAL_SPLITTER (window->content_hbox));
-	}
+	nautilus_horizontal_splitter_expand
+		(NAUTILUS_HORIZONTAL_SPLITTER (window->content_hbox));
 	nautilus_window_update_show_hide_menu_items (window);
 }
 
@@ -2157,7 +2129,8 @@ nautilus_window_sidebar_showing (NautilusWindow *window)
 {
 	g_return_val_if_fail (NAUTILUS_IS_WINDOW (window), FALSE);
 
-	return window->sidebar != NULL && GTK_WIDGET_VISIBLE (window->sidebar);
+	return GTK_IS_PANED (window->content_hbox)
+		&& gtk_paned_get_position (GTK_PANED (window->content_hbox)) != 0;
 }
 
 void 
@@ -2260,7 +2233,7 @@ nautilus_window_get_ui_container (NautilusWindow *window)
 {
 	g_return_val_if_fail (NAUTILUS_IS_WINDOW (window), CORBA_OBJECT_NIL);
 
-	return bonobo_object_corba_objref (BONOBO_OBJECT (window->details->ui_container));
+	return BONOBO_OBJREF (window->details->ui_container);
 }
 
 void
